@@ -195,14 +195,13 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Enviar recordatorios a los asistentes del calendario también",
     "Reminders are always sent to organizers and attendees." : "Los recordatorios siempre se envían a los organizadores y asistentes.",
     "Enable notifications for events via push" : "Habilitar notificaciones para eventos mediante push",
+    "Cancel" : "Cancelar",
+    "Import" : "Importar",
+    "Error while saving settings" : "Error al guardar la configuración.",
     "There was an error updating your attendance status." : "Hubo un error al actualizar tu estado de asistencia.",
     "Please contact the organizer directly." : "Por favor, contacta directamente al organizador.",
     "Are you accepting the invitation?" : "¿Aceptas la invitación?",
     "Tentative" : "Tentativo",
-    "Your attendance was updated successfully." : "Tu asistencia se actualizó correctamente.",
-    "Time:" : "Hora:",
-    "Could not open file" : "No se pudo abrir el archivo",
-    "Invalid chunk name" : "Nombre de fragmento no válido",
-    "Could not rename part file assembled from chunks" : "No se pudo renombrar el archivo parcial ensamblado a archivo final"
+    "Your attendance was updated successfully." : "Tu asistencia se actualizó correctamente."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
