@@ -223,14 +223,13 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Invia notifiche di promemoria anche ai partecipanti al calendario",
     "Reminders are always sent to organizers and attendees." : "I promemoria vengono sempre inviati agli organizzatori e ai partecipanti.",
     "Enable notifications for events via push" : "Abilita notifiche per eventi tramite push",
+    "Cancel" : "Annulla",
+    "Import" : "Importa",
+    "Error while saving settings" : "Errore durante il salvataggio delle impostazioni",
     "There was an error updating your attendance status." : "Si è verificato un errore durante l'aggiornamento dello stato della tua partecipazione.",
     "Please contact the organizer directly." : "Contatta direttamente l'amministratore.",
     "Are you accepting the invitation?" : "Accetti l'invito?",
     "Tentative" : "Provvisorio",
-    "Your attendance was updated successfully." : "La tua partecipazione è stata aggiornata correttamente.",
-    "Time:" : "Ora:",
-    "Could not open file" : "Impossibile aprire il file",
-    "Invalid chunk name" : "Nome non valido per lo spezzone",
-    "Could not rename part file assembled from chunks" : "Non è possibile rinominare il file assemblato da più spezzoni"
+    "Your attendance was updated successfully." : "La tua partecipazione è stata aggiornata correttamente."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
