@@ -51,7 +51,6 @@ OC.L10N.register(
     "Favorite files" : "Gogoko fitxategiak",
     "No favorites" : "Gogokorik ez",
     "More favorites" : "Gogoko gehiago",
-    "Upload (max. %s)" : "Igo (%s gehienez)",
     "Accept" : "Onartu",
     "Reject" : "Ukatu",
     "Incoming ownership transfer from {user}" : "{user}(r)en jabetza-transferentzia",
@@ -252,11 +251,11 @@ OC.L10N.register(
     "Cancelled move or copy operation" : "Mugitze edo kopiatze operazioa utzi da",
     "Open folder {displayName}" : "Ireki {displayName} karpeta",
     "Open in Files" : "Ireki Fitxategiak aplikazioan",
+    "Open locally" : "Ireki lokalean",
+    "Failed to redirect to client" : "Bezerora birbideratzeak huts egin du",
     "Open file locally" : "Ireki fitxategia lokalean",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Fitxategia orain zure gailuan ireki beharko litzateke. Hala ez bada, egiaztatu mahaigaineko aplikazioa instalatuta duzula.",
     "Retry and close" : "Saiatu berriro eta itxi",
-    "Failed to redirect to client" : "Bezerora birbideratzeak huts egin du",
-    "Open locally" : "Ireki lokalean",
     "Rename" : "Berrizendatu",
     "Open details" : "Ireki xehetasunak",
     "View in folder" : "Ikusi karpetan",
@@ -398,32 +397,22 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "Esteka zuzena kopiatu da (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
     "Path" : "Bidea",
     "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
-    "Favorited" : "Gogoko gisa markatua",
+    "Favored" : "Mesedetua",
+    "Favor" : "Mesedea",
     "Copy direct link (only works for people who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
     "Upload file" : "Igo fitxategia",
-    "Not favorited" : "Ez da gogokoa",
+    "Not favored" : "Mesedetu gabe",
     "An error occurred while trying to update the tags" : "Errore bat gertatu da etiketak eguneratzen saiatzean",
-    "Storage informations" : "Biltegiaren informazioak",
-    "Choose file" : "Aukeratu fitxategia",
-    "Go to the previous folder" : "Joan aurreko karpetara",
-    "Open the files app settings" : "Ireki Fitxategiak aplikazioaren ezarpenak",
-    "Unable to change the favourite state of the file" : "Ezin da fitxategiaren gogoko egoera aldatu",
-    "Edit file locally" : "Editatu fitxategia lokalean",
-    "Edit online" : "Editatu sarean",
-    "Create new templates folder" : "Sortu txantiloi karpeta berria",
+    "Upload (max. %s)" : "Igo (%s gehienez)",
+    "Submitting fields…" : "Eremuak bidaltzen…",
+    "Filter filenames…" : "Iragazi fitxategi-izenak...",
     "_{folderCount} folder_::_{folderCount} folders_" : ["Karpeta {folderCount}","{folderCount} karpeta"],
     "_{fileCount} file_::_{fileCount} files_" : ["Fitxategi {fileCount}","{fileCount} fitxategi"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["Fitxategi 1 eta karpeta {folderCount}","Fitxategi 1 eta {folderCount} karpeta"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["Fitxategi {fileCount} eta karpeta 1","{fileCount} fitxategi eta karpeta 1"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} fitxategi eta {folderCount} fitxategi",
-    "List of favorites files and folders." : "Fitxategi eta karpeta gogokoen zerrenda.",
     "Personal Files" : "Fitxategi pertsonalak",
     "Text file" : "Testu-fitxategia",
-    "New text file.txt" : "Testu-fitxategi berria.txt",
-    "Favored" : "Mesedetua",
-    "Favor" : "Mesedea",
-    "Not favored" : "Mesedetu gabe",
-    "Submitting fields…" : "Eremuak bidaltzen…",
-    "Filter filenames…" : "Iragazi fitxategi-izenak..."
+    "New text file.txt" : "Testu-fitxategi berria.txt"
 },
 "nplurals=2; plural=(n != 1);");
