@@ -46,12 +46,20 @@ OC.L10N.register(
     "Failed to authorize" : "Overitev je spodletela",
     "Invalid folder path" : "Neveljavna pot mape",
     "Folder not found" : "Mape ni mogoče najti",
-    "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
+    "The file cannot be found" : "Datoteke ni mogoče najti.",
+    "The destination path does not exist: %1$s" : "Cilja pot ne obstaja: %1$s",
+    "You do not have permission to create a file at the specified location" : "Nimate pravice za stvarjenje datoteke na podani lokaciji",
+    "The file could not be converted." : "Datoteke ni mogoče pretvoriti.",
+    "Could not get relative path to converted file" : "Ni mogoče pridobiti relativne poti do pretvorjene datoteke.",
+    "Favorite files" : "Priljubljene datoteke",
+    "No favorites" : "Ni priljubljenih datotek",
+    "More favorites" : "Več priljubljenih",
     "Accept" : "Sprejmi",
     "Reject" : "Zavrni",
     "Incoming ownership transfer from {user}" : "Vpisana je zahteva za prenos lastništva uporabnika {user}",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Ali želite sprejeti pot {path}?\n\nOpomba: po sprejetju lahko prenos traja tudi več kot 1 uro.",
     "Ownership transfer denied" : "Prenos lastništva je spodletel",
+    "Your ownership transfer of {path} was denied by {user}." : "Prenos lastništva za {path} je onemogočil {user}.",
     "Ownership transfer failed" : "Prenos lastništva je spodletel",
     "Your ownership transfer of {path} to {user} failed." : "Prenos lastništva mesta {path} na uporabnika {user} je spodletel.",
     "The ownership transfer of {path} from {user} failed." : "Prenos lastništva mesta {path} na uporabnika {user} je spodletel.",
@@ -59,62 +67,72 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "Prenos lastništva poti {path} na uporabnika {user} je končan.",
     "The ownership transfer of {path} from {user} has completed." : "Prenos lastništva poti {path} z uporabnika {user} je končan.",
     "in %s" : "v %s",
+    "Transferred from %1$s on %2$s" : "Preneseno iz %1$s na %2$s",
     "Files compatibility" : "Skladnost datotek",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Dovoli omejitev imen datotek za zagotovitev sinhronizacije datotek z vsemi odjemalci. Privzeto je dovoljenje za vsa imena datotek na POSIX (tj. Linux ali macOS).",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Po vklopu imen, ki so združljiva z WIndows, obstoječih datotek ni več mogoče spreminjati, jih pa lahko lastnik preimenuje v ustrezno ime.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Datoteke lahko po vklopu te možnosti tudi same migrirajo. Preverite dokumentacijo o ukazu occ.",
     "Enforce Windows compatibility" : "Vsili skladnost s sistemom Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "To bo blokiralo imena datotek, ki niso ustrezna za Windows sisteme, kot so rezervirana imena ali posebni znaki, ne bo pa to vsililo združljivosti pri razlikovanju velikih in malih črk imena.",
     "File Management" : "Upravljanje datotek",
-    "Current directory path" : "Trenutna pot mape",
     "Home" : "Začetni pogled",
     "Target folder does not exist any more" : "Ciljna mapa ne obstaja več",
     "Reload current directory" : "Ponovno naloži trenutno mapo",
     "Go to the \"{dir}\" directory" : "Pojdi v mapo »{dir}«",
+    "Current directory path" : "Trenutna pot mape",
+    "Your have used your space quota and cannot upload files anymore" : "Porabili ste svojo količino prostora in datotek več ne morete nalagati",
+    "You do not have permission to upload or create files here." : "Nimate pravic za ustvarjanje ali nalaganje datotek na to mesto.",
     "Drag and drop files here to upload" : "Za pošiljanje potegnite in spustite datoteke na to mesto",
-    "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje in ustvarjanje datotek na tem mestu.",
     "Favorite" : "Priljubljene",
-    "\"{displayName}\" action executed successfully" : "Dejanje »{displayName}« je uspešno izvedeno",
-    "\"{displayName}\" action failed" : "Dejanje »{displayName}« je spodletelo",
+    "Back" : "Nazaj",
+    "Toggle selection for file \"{displayName}\"" : "Preklopi izbor za datoteko \"{displayName}\"",
+    "Toggle selection for folder \"{displayName}\"" : "Preklopi izbor za mapo \"{displayName}\"",
     "File is loading" : "Poteka nalaganje datoteke",
     "Folder is loading" : "mape",
-    "Rename file" : "Preimenuj datoteke",
     "Filename" : "Ime datoteke",
     "Folder name" : "Ime mape",
     "This node is unavailable" : "To vozlišče ni na voljo.",
+    "Another entry with the same name already exists." : "Vpis z istim imenom že obstaja.",
     "Invalid filename." : "Neveljavno ime datoteke",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Preimenuj »{oldName}« to »{newName}«",
+    "Rename file" : "Preimenuj datoteke",
+    "Folder" : "Mapa",
     "Pending" : "Na čakanju ...",
+    "Unknown date" : "Neznani datum",
     "Clear filter" : "Počisti filter",
     "Modified" : "Spremenjeno",
     "Type" : "Vrsta",
     "Active filters" : "Dejavni filtri",
     "Remove filter" : "Odstrani filter",
     "Total rows summary" : "Skupni povzetek vrstic",
+    "Toggle selection for all files and folders" : "Preklopi izbor za vse datoteke in mape",
     "Name" : "Ime",
     "Size" : "Velikost",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" ni uspel za nekatere elemente",
+    "\"{displayName}\" batch action executed successfully" : "Paketno dejanje »{displayName}« je uspešno izvedeno",
+    "\"{displayName}\" action failed" : "Dejanje »{displayName}« je spodletelo",
     "Actions" : "Dejanja",
     "(selected)" : "(izbrano)",
-    "\"{displayName}\" failed on some elements " : "Dejanje »{displayName}« je pri nekaterih predmetih spodletelo",
-    "\"{displayName}\" batch action executed successfully" : "Paketno dejanje »{displayName}« je uspešno izvedeno",
-    "{count} selected" : "{count} izbranih",
     "List of files and folders." : "Seznam datotek in map",
+    "You have used your space quota and cannot upload files anymore." : "Porabili ste svojo količino prostora in datotek več ne morete nalagati",
+    "Column headers with buttons are sortable." : "Naslove stolpcev z gumbi je mogoče sortirati.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Seznam datotek ni v celoti izpisan zaradi zagotavljanja hitrosti in odzivnosti sistema. Predmeti se bodo dopolnjevali med brskanjem.",
     "File not found" : "Datoteke ni mogoče najti",
-    "Storage information" : "Podrobnosti shrambe",
-    "Storage quota" : "Omejitev shrambe",
+    "{count} selected" : "{count} izbranih",
     "{usedQuotaByte} used" : "Zasedeno {usedQuotaByte}",
     "{used} of {quota} used" : "V uporabi je {used} od {quota}",
     "{relative}% used" : "Zasedeno {relative} %",
     "Could not refresh storage stats" : "Ni mogoče osvežiti podatkov shrambe",
     "Your storage is full, files can not be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
-    "Create" : "Ustvari",
+    "Storage information" : "Podrobnosti shrambe",
+    "Storage quota" : "Omejitev shrambe",
     "New folder" : "Nova mapa",
     "Create new folder" : "Ustvari novo mapo",
     "This name is already in use." : "Vpisano uporabniško ime je že v uporabi",
+    "Create" : "Ustvari",
     "Fill template fields" : "Zapolni polja predloge",
-    "Submitting fields…" : "Poteka objavljanje vsebine polj ...",
+    "Submitting fields …" : "Pošiljanje polj ...",
     "Submit" : "Pošlji",
-    "Transfer ownership of a file or folder" : "Prenos lastništva datoteke ali mape",
-    "Choose file or folder to transfer" : "Izbor datoteke ali mape za prenos",
-    "Change" : "Spremeni",
-    "New owner" : "Nov lastnik",
     "Choose a file or folder to transfer" : "Izbor datoteke ali mape za prenos",
     "Transfer" : "Prenos",
     "Transfer {path} to {userid}" : "Prenesi pot {path} k uporabniku {userid}",
@@ -122,28 +140,48 @@ OC.L10N.register(
     "Unknown error" : "Neznana napaka",
     "Ownership transfer request sent" : "Zahteva za prenos lastništva je poslana",
     "Cannot transfer ownership of a file or folder you do not own" : "Ni mogoče prenesti lastništva datotek in map, katerih niste lastnik",
+    "Transfer ownership of a file or folder" : "Prenos lastništva datoteke ali mape",
+    "Choose file or folder to transfer" : "Izbor datoteke ali mape za prenos",
+    "Change" : "Spremeni",
+    "New owner" : "Nov lastnik",
+    "Keep {old}" : "Ohrani {old}",
+    "Keep without extension" : "Ohrani brez pripone",
+    "Use {new}" : "Uporabi {new}",
+    "Remove extension" : "Odstrani pripono",
+    "Change file extension" : "Spremeni pripono datoteke",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Sprememba končnice datoteke iz \"{old}\" v \"{new}\" lahko naredi datoteko neberljivo.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "Odstranitev končnice datoteke \"{old}\" lahko naredi datoteko neberljivo.",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "Dadajanje končnice datoteke \"{new}\" lahko naredi datoteko neberljivo.",
+    "Do not show this dialog again." : "Pogovornega okna ne pokaži več.",
     "Select file or folder to link to" : "Izbor datoteke ali mape za povezavo",
     "Choose {file}" : "Izberite datoteko {file}",
-    "Loading current folder" : "Poteka nalaganje trenutne mape",
-    "Retry" : "Poskusi znova",
-    "No files in here" : "V mapi ni datotek",
-    "Upload some content or sync with your devices!" : "Uvozite vsebino, ali pa omogočite usklajevanje z napravami!",
-    "Go back" : "Skoči nazaj",
     "Share" : "·Souporaba·",
     "Shared by link" : "V souporabi sk povezavo",
     "Shared" : "V souporabi",
     "Switch to list view" : "Preklopi na seznamski pogled",
     "Switch to grid view" : "Preklopi na mrežni pogled",
+    "The file could not be found" : "Datoteke ni mogoče najti.",
     "Upload was cancelled by user" : "Uporabnik je pošiljanje preklical",
     "Not enough free space" : "Ni dovolj prostora",
     "Operation is blocked by access control" : "Opravilo je zaustavljeno prek nadzora dostopa",
+    "Error during upload: {message}" : "Napaka med nalaganjem: {message}",
+    "Error during upload, status code {status}" : "Napaka med nalaganje s kodo stanja {status}",
     "Unknown error during upload" : "Med pošiljanjem je prišlo do neznane napake",
-    "Filter filenames…" : "Filtriraj imena datotek ...",
+    "\"{displayName}\" action executed successfully" : "Dejanje »{displayName}« je uspešno izvedeno",
+    "Loading current folder" : "Poteka nalaganje trenutne mape",
+    "Retry" : "Poskusi znova     ",
+    "No files in here" : "V mapi ni datotek",
+    "Upload some content or sync with your devices!" : "Uvozite vsebino, ali pa omogočite usklajevanje z napravami!",
+    "Go back" : "Skoči nazaj",
+    "Filter file names …" : "Filtriraj imena datotek...",
     "Views" : "Pogledi",
     "Files settings" : "Nastavitve datotek",
-    "File cannot be accessed" : "Do datoteke dostop ni mogoč",
     "Your files" : "Osebne datoteke",
     "Open in files" : "Odpri datoteko v mapi",
+    "File cannot be accessed" : "Do datoteke dostop ni mogoč",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Datoteke ni bilo mogoče najti ali pa nimate ustreznih dovoljenj za ogled. Prosite pošiljatelja, da jo deli.",
+    "Clipboard is not available" : "Odložišče ni na voljo",
+    "WebDAV URL copied to clipboard" : "Naslov URL WebDAV je kopiran v odložišče",
     "Sort favorites first" : "Razvrsti najprej priljubljene",
     "Sort folders before files" : "Razvrsti mape pred datotekami",
     "Show hidden files" : "Pokaži skrite datoteke",
@@ -156,19 +194,57 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopiraj v odložišče",
     "Use this address to access your Files via WebDAV" : "Uporabite ta naslov za dostop do datotek z uporabo WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Če je omogočen sistem dvostopenjskega overjanja 2FA, je treba ustvariti in uporabiti novo geslo programa s klikom na to mesto.",
-    "Clipboard is not available" : "Odložišče ni na voljo",
-    "WebDAV URL copied to clipboard" : "Naslov URL WebDAV je kopiran v odložišče",
+    "Warnings" : "Opozorila",
+    "Prevent warning dialogs from open or reenable them." : "Preprečite odpiranje dialogov z opozorili ali jih ponovno omogočite.",
+    "Show a warning dialog when changing a file extension." : "Prikaži opozorilo ob spreminjanju končnice datoteke.",
+    "Keyboard shortcuts" : "Tipkovne bližnjice",
+    "Speed up your Files experience with these quick shortcuts." : "Pospešite uporabo upravljalnika Files s temi bližnjicami.",
+    "Open the actions menu for a file" : "Odpri meni dejanj za datoteko",
+    "Rename a file" : "Preimenuj datoteko",
+    "Delete a file" : "Izbriši datoteko",
+    "Favorite or remove a file from favorites" : "Označi ali odstrani koz priljubljeno",
+    "Manage tags for a file" : "Upravljanje oznak datoteke",
+    "Selection" : "Izbor",
+    "Select all files" : "Izberi vse datoteke",
+    "Deselect all files" : "Ostrani izbor vseh datotek",
+    "Select or deselect a file" : "Izberi ali odstrani izbor datoteke",
+    "Select a range of files" : "Izbor obsega datotek",
+    "Navigation" : "Krmarjenje",
+    "Navigate to the parent folder" : "Pojdi na nadrejeni imenik",
+    "Navigate to the file above" : "Pojdi na datoteko zgoraj",
+    "Navigate to the file below" : "Pojdi na doatoteko spodaj",
+    "Navigate to the file on the left (in grid mode)" : "Pojdi na datoteko na levi (v mrežnem načinu)",
+    "Navigate to the file on the right (in grid mode)" : "Pojdi na datoteko na desni (v mrežnem načinu)",
+    "View" : "Pogled",
+    "Toggle the grid view" : "Preklopi mrežni način",
+    "Open the sidebar for a file" : "Odpri stranski pano datoteke",
+    "Show those shortcuts" : "Pokaži tipkovne bližnjice",
+    "You" : "Jaz",
+    "Shared multiple times with different people" : "V več souporabah z različnimi uporabniki",
+    "Error while loading the file data" : "Prišlo je do napake med nalaganjem podatkov računa",
+    "Owner" : "Lastnik",
     "Remove from favorites" : "Odstrani iz priljubljenih",
     "Add to favorites" : "Dodaj med priljubljene",
     "Tags" : "Oznake",
-    "You" : "Jaz",
-    "Unable to change the favourite state of the file" : "Ni mogoče spremeniti stanja priljubljenosti datoteke",
-    "Error while loading the file data" : "Prišlo je do napake med nalaganjem podatkov računa",
+    "Blank" : "Prazno",
+    "Unable to create new file from template" : "Nove datoteke iz predloge ni mogoče ustvariti",
     "Pick a template for {name}" : "Izbor predloge za {name}",
     "Create a new file with the selected template" : "Ustvari novo datoteko z izbrano predlogo",
     "Creating file" : "Poteka ustvarjanje datoteke",
-    "Blank" : "Prazno",
-    "Unable to create new file from template" : "Nove datoteke iz predloge ni mogoče ustvariti",
+    "Save as {displayName}" : "Shrani kot {displayName}",
+    "Save as …" : "Shrani kot ...",
+    "Converting files …" : "Poteka pretvarjanje datotek ...",
+    "Failed to convert files: {message}" : "Pretvarjanje datotek je spodletelo: {message}",
+    "All files failed to be converted" : "Spodletelo je pretvarjanje vseh datotek.",
+    "One file could not be converted: {message}" : "Ene datoteke ni mogoče pretvoriti: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["%n datoteke ni mogoče pretvoriti","%n datotek ni mogoče pretvoriti","%n datotek ni mogoče pretvoriti","%n datotek ni mogoče pretvoriti"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["%n datoteka je uspešno pretvorjena","%n datoteki sta uspešno pretvorjeni","%n datoteke so uspešno pretvorjene","%n datotek je uspešno pretvorjenih"],
+    "Files successfully converted" : "Datoteke so uspešno pretvorjene",
+    "Failed to convert files" : "Pretvarjanje datotek je spodletelo",
+    "Converting file …" : "Poteka pretvarjanje datoteke ...",
+    "File successfully converted" : "Datoteka je uspešno pretvorjena",
+    "Failed to convert file: {message}" : "Pretvarjanje datoteek je spodletelo: {message}",
+    "Failed to convert file" : "Pretvarjanje datoteke je spodletelo",
     "Deletion cancelled" : "Brisanje je bilo preklicano",
     "Leave this share" : "Prekini to souporabo",
     "Leave these shares" : "Prekini to souporabo",
@@ -177,16 +253,16 @@ OC.L10N.register(
     "Delete permanently" : "Izbriši trajno",
     "Delete and unshare" : "Izbriši in prekini souporabo",
     "Delete file" : "Izbriši datoteko",
-    "Delete files" : "Izbriši datoteki",
+    "Delete files" : "Izbriši datoteke",
     "Delete folder" : "Izbriši mapo",
     "Delete folders" : "Izbriši mape",
     "Delete" : "Izbriši",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Za stalno boste izbrisali {count} predmet","Za stalno boste izbrisali {count} predmeta","Za stalno boste izbrisali {count} predmete","Za stalno boste izbrisali {count} predmetov"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Izbrisali boste {count} predmet","Izbrisali boste {count} predmeta","Izbrisali boste {count} predmete","Izbrisali boste {count} predmetov"],
     "Confirm deletion" : "Potrdi brisanje",
     "Cancel" : "Prekliči",
-    "Edit file locally" : "Uredi datoteko krajevno",
-    "Edit online" : "Uredi na spletu",
-    "Failed to redirect to client" : "Preusmerjanje odjemalca je spodletelo",
-    "Edit locally" : "Uredi krajevno",
+    "Moving \"{source}\" to \"{destination}\" …" : "Premik \"{source}\" v \"{destination}\"...",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopiranje \"{source}\" v \"{destination}\"...",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Mape ali datoteke ni mogoče premakniti samo vase oziroma v podmapo same sebe",
     "(copy)" : "(kopija)",
     "(copy %n)" : "(kopija %n)",
@@ -201,9 +277,16 @@ OC.L10N.register(
     "Move" : "Premakni",
     "Move or copy operation failed" : "Opravilo kopiranja oziroma premikanja je spodletelo",
     "Move or copy" : "Premakni ali kopiraj",
+    "Cancelled move or copy of \"{filename}\"." : "Prekinjeno premikanje ali kopiranje za \"{filename}\".",
     "Cancelled move or copy operation" : "Opravilo kopiranje in premikanja je preklicano",
     "Open folder {displayName}" : "Odpri mapo {displayName}",
     "Open in Files" : "Open in Files",
+    "Open locally" : "Odpri krajevno",
+    "Failed to redirect to client" : "Preusmerjanje odjemalca je spodletelo",
+    "Open file locally" : "Odpri datoteko krajevno",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Datoteka bi se sedaj morala odpreti z vaše naprave. Če se to ne zgodi, preverite namestitev namizne aplikacije.",
+    "Retry and close" : "Ponovno poskusi in zapri",
+    "Open online" : "Odpri v brskalniku",
     "Rename" : "Preimenuj",
     "Open details" : "Odpri podrobnosti",
     "View in folder" : "Pokaži v mapi",
@@ -228,7 +311,10 @@ OC.L10N.register(
     "New template folder" : "Nova mapa predlog",
     "In folder" : "V mapi",
     "Search in folder: {folder}" : "Išči v mapi: {folder}",
+    "One of the dropped files could not be processed" : "Eno od podanih datotek ni bilo mogoče obdelati",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Brskalnik ne podpira API datotečnega sistema. Mape ne bodo naložene",
     "No files to upload" : "Ni datotek za pošiljanje",
+    "Unable to create the directory {directory}" : "Mape {directory} ni mogoče ustvariti",
     "Some files could not be uploaded" : "Nekaterih datotek ni bilo mogoče poslati",
     "Files uploaded successfully" : "Datoteke so uspešno poslane v oblak",
     "No files to process" : "Ni datotek za obdelavo",
@@ -241,24 +327,29 @@ OC.L10N.register(
     "This operation is forbidden" : "To dejanje ni dovoljeno!",
     "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
     "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mapa","{folderCount} mapi","{folderCount} mape","{folderCount} map"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} datoteka","{fileCount} datoteki","{fileCount} datoteke","{fileCount} datotek"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 datoteka in {folderCount} mapa","1 datoteka in {folderCount} mapi","1 datoteka in {folderCount} mape","1 datoteka in {folderCount} map"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} datoteka in 1 mapa","{fileCount} datoteki in 1 mapa","{fileCount} datoteke in 1 mapa","{fileCount} datotek in 1 mapa"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} datotek in {folderCount} map",
+    "Unexpected error: {error}" : "Nepričakovana napaka: {error}",
+    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
+    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
+    "_%n hidden_::_%n hidden_" : ["%n skrita","%n skriti","%n skrite","%n skritih"],
     "Filename must not be empty." : "Ime datoteke ne sme biti prazno.",
+    "\"{char}\" is not allowed inside a filename." : "Znak \"{char}\" ni dovoljen v imenu datotek.",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" je rezervirano ime in ni dovoljeno za ime datoteke.",
+    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" ni dovoljena vrsta končnice.",
+    "Filenames must not end with \"{extension}\"." : "Imena datotek naj nimajo končnice \"{extension}\".",
+    "List of favorite files and folders." : "Seznam priljubljenih datotek in map.",
     "No favorites yet" : "Ni še dodanih priljubljenih predmetov",
     "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
     "All files" : "Vse datoteke",
     "List of your files and folders." : "Seznam datotek in map.",
     "All folders" : "Vse mape",
-    "Personal Files" : "Osebne datoteke",
+    "Personal files" : "Osebne datoteke",
+    "List of your files and folders that are not shared." : "Seznam datotek in map, ki niso v skupni rabi.",
     "No personal files found" : "Ni najdenih zasebnih datotek",
+    "Files that are not shared will show up here." : "Datoteke, ki niso v skupni rabi, bodo prikazane tukaj.",
     "Recent" : "Nedavne",
     "List of recently modified files and folders." : "Seznam nedavno spremenjenih datotek in map.",
     "No recently modified files" : "Ni nedavno spremenjenih datotek",
     "Files and folders you recently modified will show up here." : "Nedavno spremenjene datoteke ali mape, bodo zbrane na tem mestu.",
-    "You do not have permission to upload or create files here" : "Ni ustreznih dovoljenja za pošiljanje ali ustvarjanje novih datotek",
     "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
     "Select all" : "izberi vse",
     "Upload too large" : "Prekoračena je omejitev dovoljene velikosti",
@@ -286,6 +377,7 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Napaka pri sestavljanju kosov datoteke, koda stanja je {status}",
     "Choose target folder" : "Izbor ciljne mape",
     "Set reminder" : "Nastavi opomnik",
+    "Edit locally" : "Uredi krajevno",
     "Open" : "Odpri",
     "Could not load info for file \"{file}\"" : "Ni mogoče naložiti podatkov za datoteko »{file}«.",
     "Details" : "Podrobnosti",
@@ -312,10 +404,9 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Prišli je do napake med brisanjem datoteke »{fileName}«.",
     "No search results in other folders for {tag}{filter}{endtag}" : "Za iskalni niz {tag}{filter}{endtag} ni zadetkov v nobeni mapi",
     "Enter more than two characters to search in other folders" : "Vpišite več kot dva znaka za iskanje po drugih mapah",
-    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
-    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
     "{dirs} and {files}" : "{dirs} in {files}",
     "_including %n hidden_::_including %n hidden_" : ["vključujoč %n skrito","vključujoč %n skriti","vključujoč %n skrite","vključujoč %n skritih"],
+    "You do not have permission to upload or create files here" : "Ni ustreznih dovoljenja za pošiljanje ali ustvarjanje novih datotek",
     "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Poteka posodabljanje %n datotek"],
     "New" : "Novo",
     "New file/folder menu" : "Nov meni datoteke/mape",
@@ -335,33 +426,25 @@ OC.L10N.register(
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Zunanja shramba »{mountPoint}« je skoraj do konca zasedena ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Vaša shramba je skoraj do konca zasedena ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["se skladajo s filtrom »{filter}«","se skladajo s filtroma »{filter}«","se skladajo s filtri »{filter}«","se skladajo s filtri »{filter}«"],
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Kopirana je neposredna povezava (za uporabnike, ki imajo dostop do datoteke ali mape)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Kopirana je neposredna povezava (za uporabnike, ki imajo dostop do datoteke ali mape)",
     "Path" : "Pot",
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
-    "Favorited" : "Označeno kot priljubljeno",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
+    "Favored" : "Priljubljeno",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
     "Upload file" : "Pošlji datoteko",
-    "Not favorited" : "Ni priljubljeno",
     "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
-    "\"remote user\"" : "»Oddaljen uporabnik«",
-    "{newName} already exists." : "Ime {newName} že obstaja.",
-    "Name cannot be empty" : "Polje imena ne sme biti prazno",
-    "Another entry with the same name already exists" : "Vpis s tem imenom že obstaja.",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Datoteke »{oldName}« ni mogoče preimenovati, ker ne obstaja več.",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime »{newName}« je v mapi »{dir}« že v uporabi. Izbrati je treba drugačno ime.",
-    "Could not rename \"{oldName}\"" : "Datoteke »{oldName}« ni mogoče preimenovati",
-    "Storage informations" : "Podrobnosti shrambe",
-    "Choose file" : "Izbor datotek",
-    "Go to the previous folder" : "Skoči na predhodno mapo",
-    "Open the files app settings" : "Odpri nastavitve programa Datoteke",
-    "You might not have have permissions to view it, ask the sender to share it" : "Morda ni ustreznih dovoljenj za ogled. Prosite pošiljatelja za prilagoditev.",
-    "The files is locked" : "Datoteka je zaklenjena",
-    "Create new templates folder" : "Ustvari novo začasno mapo",
-    "List of favorites files and folders." : "Seznam priljubljenih datotek in map.",
-    "Toggle %1$s sublist" : "Preklopi podseznam %1$s",
+    "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
+    "Submitting fields…" : "Poteka objavljanje vsebine polj ...",
+    "Filter filenames…" : "Filtriraj imena datotek ...",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mapa","{folderCount} mapi","{folderCount} mape","{folderCount} map"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} datoteka","{fileCount} datoteki","{fileCount} datoteke","{fileCount} datotek"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 datoteka in {folderCount} mapa","1 datoteka in {folderCount} mapi","1 datoteka in {folderCount} mape","1 datoteka in {folderCount} map"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} datoteka in 1 mapa","{fileCount} datoteki in 1 mapa","{fileCount} datoteke in 1 mapa","{fileCount} datotek in 1 mapa"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} datotek in {folderCount} map",
+    "Personal Files" : "Osebne datoteke",
     "Text file" : "Besedilna datoteka",
     "New text file.txt" : "nova_datoteka.txt",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Kopirana je neposredna povezava (za uporabnike, ki imajo dostop do datoteke ali mape)",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)"
+    "{count} files could not be converted" : "{count} datotek ni mogoče pretvoriti",
+    "{count} files successfully converted" : "{count} datotek je uspešno pretvorjenih"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
