@@ -1,30 +1,13 @@
 <?php
-/**
- * @copyright Copyright (c) 2016, ownCloud, Inc.
- *
- * @author Joas Schilling <coding@schilljs.com>
- * @author Lukas Reschke <lukas@statuscode.ch>
- * @author Robin Appelman <robin@icewind.nl>
- * @author Robin McCorkell <robin@mccorkell.me.uk>
- *
- * @license AGPL-3.0
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
- */
 
+/**
+ * SPDX-FileCopyrightText: 2018-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
+ */
 namespace OCA\Files_External\Service;
 
+use Doctrine\DBAL\Exception\UniqueConstraintViolationException;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
 use OCP\Security\ICrypto;
@@ -33,12 +16,14 @@ use OCP\Security\ICrypto;
  * Stores the mount config in the database
  */
 class DBConfigService {
-	const MOUNT_TYPE_ADMIN = 1;
-	const MOUNT_TYPE_PERSONAl = 2;
+	public const MOUNT_TYPE_ADMIN = 1;
+	public const MOUNT_TYPE_PERSONAL = 2;
+	/** @deprecated use MOUNT_TYPE_PERSONAL (full uppercase) instead */
+	public const MOUNT_TYPE_PERSONAl = 2;
 
-	const APPLICABLE_TYPE_GLOBAL = 1;
-	const APPLICABLE_TYPE_GROUP = 2;
-	const APPLICABLE_TYPE_USER = 3;
+	public const APPLICABLE_TYPE_GLOBAL = 1;
+	public const APPLICABLE_TYPE_GROUP = 2;
+	public const APPLICABLE_TYPE_USER = 3;
 
 	/**
 	 * @var IDBConnection
@@ -61,11 +46,7 @@ class DBConfigService {
 		$this->crypto = $crypto;
 	}
 
-	/**
-	 * @param int $mountId
-	 * @return array
-	 */
-	public function getMountById($mountId) {
+	public function getMountById(int $mountId): ?array {
 		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->select(['mount_id', 'mount_point', 'storage_backend', 'auth_backend', 'priority', 'type'])
 			->from('external_mounts', 'm')
@@ -113,11 +94,42 @@ class DBConfigService {
 		return $this->getMountsFromQuery($query);
 	}
 
+	public function modifyMountsOnUserDelete(string $uid): void {
+		$this->modifyMountsOnDelete($uid, self::APPLICABLE_TYPE_USER);
+	}
+
+	public function modifyMountsOnGroupDelete(string $gid): void {
+		$this->modifyMountsOnDelete($gid, self::APPLICABLE_TYPE_GROUP);
+	}
+
+	protected function modifyMountsOnDelete(string $applicableId, int $applicableType): void {
+		$builder = $this->connection->getQueryBuilder();
+		$query = $builder->select(['a.mount_id', $builder->func()->count('a.mount_id', 'count')])
+			->from('external_applicable', 'a')
+			->leftJoin('a', 'external_applicable', 'b', $builder->expr()->eq('a.mount_id', 'b.mount_id'))
+			->where($builder->expr()->andX(
+				$builder->expr()->eq('b.type', $builder->createNamedParameter($applicableType, IQueryBuilder::PARAM_INT)),
+				$builder->expr()->eq('b.value', $builder->createNamedParameter($applicableId))
+			)
+			)
+			->groupBy(['a.mount_id']);
+		$stmt = $query->execute();
+		$result = $stmt->fetchAll();
+		$stmt->closeCursor();
+
+		foreach ($result as $row) {
+			if ((int) $row['count'] > 1) {
+				$this->removeApplicable($row['mount_id'], $applicableType, $applicableId);
+			} else {
+				$this->removeMount($row['mount_id']);
+			}
+		}
+	}
+
 	/**
 	 * Get admin defined mounts
 	 *
 	 * @return array
-	 * @suppress SqlInjectionChecker
 	 */
 	public function getAdminMounts() {
 		$builder = $this->connection->getQueryBuilder();
@@ -162,7 +174,6 @@ class DBConfigService {
 	 * @param int $type any of the self::APPLICABLE_TYPE_ constants
 	 * @param string|null $value user_id, group_id or null for global mounts
 	 * @return array
-	 * @suppress SqlInjectionChecker
 	 */
 	public function getAdminMountsFor($type, $value) {
 		$builder = $this->connection->getQueryBuilder();
@@ -178,7 +189,6 @@ class DBConfigService {
 	 * @param int $type any of the self::APPLICABLE_TYPE_ constants
 	 * @param string[] $values user_ids or group_ids
 	 * @return array
-	 * @suppress SqlInjectionChecker
 	 */
 	public function getAdminMountsForMultiple($type, array $values) {
 		$builder = $this->connection->getQueryBuilder();
@@ -202,12 +212,11 @@ class DBConfigService {
 	 * @param int $type any of the self::APPLICABLE_TYPE_ constants
 	 * @param string|null $value user_id, group_id or null for global mounts
 	 * @return array
-	 * @suppress SqlInjectionChecker
 	 */
 	public function getUserMountsFor($type, $value) {
 		$builder = $this->connection->getQueryBuilder();
 		$query = $this->getForQuery($builder, $type, $value);
-		$query->andWhere($builder->expr()->eq('m.type', $builder->expr()->literal(self::MOUNT_TYPE_PERSONAl, IQueryBuilder::PARAM_INT)));
+		$query->andWhere($builder->expr()->eq('m.type', $builder->expr()->literal(self::MOUNT_TYPE_PERSONAL, IQueryBuilder::PARAM_INT)));
 
 		return $this->getMountsFromQuery($query);
 	}
@@ -236,7 +245,7 @@ class DBConfigService {
 				'type' => $builder->createNamedParameter($type, IQueryBuilder::PARAM_INT)
 			]);
 		$query->execute();
-		return (int)$this->connection->lastInsertId('*PREFIX*external_mounts');
+		return $query->getLastInsertId();
 	}
 
 	/**
@@ -250,14 +259,17 @@ class DBConfigService {
 			->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)));
 		$query->execute();
 
+		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->delete('external_applicable')
 			->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)));
 		$query->execute();
 
+		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->delete('external_config')
 			->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)));
 		$query->execute();
 
+		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->delete('external_options')
 			->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)));
 		$query->execute();
@@ -300,12 +312,15 @@ class DBConfigService {
 		if ($key === 'password') {
 			$value = $this->encryptValue($value);
 		}
-		$count = $this->connection->insertIfNotExist('*PREFIX*external_config', [
-			'mount_id' => $mountId,
-			'key' => $key,
-			'value' => $value
-		], ['mount_id', 'key']);
-		if ($count === 0) {
+
+		try {
+			$builder = $this->connection->getQueryBuilder();
+			$builder->insert('external_config')
+				->setValue('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT))
+				->setValue('key', $builder->createNamedParameter($key, IQueryBuilder::PARAM_STR))
+				->setValue('value', $builder->createNamedParameter($value, IQueryBuilder::PARAM_STR))
+				->execute();
+		} catch (UniqueConstraintViolationException $e) {
 			$builder = $this->connection->getQueryBuilder();
 			$query = $builder->update('external_config')
 				->set('value', $builder->createNamedParameter($value, IQueryBuilder::PARAM_STR))
@@ -321,13 +336,14 @@ class DBConfigService {
 	 * @param string $value
 	 */
 	public function setOption($mountId, $key, $value) {
-
-		$count = $this->connection->insertIfNotExist('*PREFIX*external_options', [
-			'mount_id' => $mountId,
-			'key' => $key,
-			'value' => json_encode($value)
-		], ['mount_id', 'key']);
-		if ($count === 0) {
+		try {
+			$builder = $this->connection->getQueryBuilder();
+			$builder->insert('external_options')
+				->setValue('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT))
+				->setValue('key', $builder->createNamedParameter($key, IQueryBuilder::PARAM_STR))
+				->setValue('value', $builder->createNamedParameter(json_encode($value), IQueryBuilder::PARAM_STR))
+				->execute();
+		} catch (UniqueConstraintViolationException $e) {
 			$builder = $this->connection->getQueryBuilder();
 			$query = $builder->update('external_options')
 				->set('value', $builder->createNamedParameter(json_encode($value), IQueryBuilder::PARAM_STR))
@@ -338,11 +354,16 @@ class DBConfigService {
 	}
 
 	public function addApplicable($mountId, $type, $value) {
-		$this->connection->insertIfNotExist('*PREFIX*external_applicable', [
-			'mount_id' => $mountId,
-			'type' => $type,
-			'value' => $value
-		], ['mount_id', 'type', 'value']);
+		try {
+			$builder = $this->connection->getQueryBuilder();
+			$builder->insert('external_applicable')
+				->setValue('mount_id', $builder->createNamedParameter($mountId))
+				->setValue('type', $builder->createNamedParameter($type))
+				->setValue('value', $builder->createNamedParameter($value))
+				->execute();
+		} catch (UniqueConstraintViolationException $e) {
+			// applicable exists already
+		}
 	}
 
 	public function removeApplicable($mountId, $type, $value) {
@@ -382,8 +403,8 @@ class DBConfigService {
 		$options = $this->getOptionsForMounts($mountIds);
 
 		return array_map(function ($mount, $applicable, $config, $options) {
-			$mount['type'] = (int)$mount['type'];
-			$mount['priority'] = (int)$mount['priority'];
+			$mount['type'] = (int) $mount['type'];
+			$mount['priority'] = (int) $mount['priority'];
 			$mount['applicable'] = $applicable;
 			$mount['config'] = $config;
 			$mount['options'] = $options;
@@ -411,7 +432,10 @@ class DBConfigService {
 		$query = $builder->select($fields)
 			->from($table)
 			->where($builder->expr()->in('mount_id', $placeHolders));
-		$rows = $query->execute()->fetchAll();
+
+		$result = $query->execute();
+		$rows = $result->fetchAll();
+		$result->closeCursor();
 
 		$result = [];
 		foreach ($mountIds as $mountId) {
@@ -419,7 +443,7 @@ class DBConfigService {
 		}
 		foreach ($rows as $row) {
 			if (isset($row['type'])) {
-				$row['type'] = (int)$row['type'];
+				$row['type'] = (int) $row['type'];
 			}
 			$result[$row['mount_id']][] = $row;
 		}
