@@ -69,6 +69,7 @@ OC.L10N.register(
     "Public link sharing is disabled by the administrator" : "Ylläpitäjä on estänyt julkisen linkin jakamisen",
     "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Kohteen %s jakaminen lähettämällä salasana Nextcloud Talkin kautta epäonnistui, koska Nextcloud Talk ei ole käytössä",
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Kohteen %1$s jakaminen epäonnistui, koska tietovarasto ei salli %2$s tyyppisiä jakoja",
+    "Please specify a valid team" : "Määritä kelvollinen tiimi",
     "Sharing %s failed because the back end does not support room shares" : "Kohteen %s jakaminen epäonnistui, koska taustaosa ei tue huonejakoja",
     "Unknown share type" : "Tuntematon jaon tyyppi",
     "Not a directory" : "Ei hakemisto",
@@ -91,16 +92,32 @@ OC.L10N.register(
     "You received {share} to group {group} as a share by {user}" : "Vastaanotit jaon {share} ryhmään {group} käyttäjältä {user}",
     "Accept" : "Hyväksy",
     "Decline" : "Kieltäydy",
+    "Open \"%s\"" : "Avaa \"%s\"",
     "People" : "Ihmiset",
+    "The request will be password protected." : "Pyyntö suojataan salasanalla.",
+    "When should the request expire?" : "Milloin pyynnön tulee vanhentua?",
     "Expiration date" : "Vanhenemispäivä",
     "Select a date" : "Valitse päivämäärä",
     "Set a password" : "Aseta salasana",
     "Password" : "Salasana",
+    "Enter a valid password" : "Kirjoita oikea salasana",
+    "Generate a new password" : "Luo uusi salasana",
+    "Your administrator has enforced a password protection." : "Ylläpitäjä on pakottanut salasanasuojauksen.",
     "Link copied to clipboard" : "Linkki kopioitu leikepöydälle",
+    "Email already added" : "Sähköpostiosoite on jo lisätty",
+    "Invalid email address" : "Virheellinen sähköpostiosoite",
     "Share link" : "Jaa linkki",
     "Copy to clipboard" : "Kopioi leikepöydälle",
     "Send link via email" : "Lähetä linkki sähköpostitse",
+    "Select a destination" : "Valitse sijainti",
     "Select" : "Valitse",
+    "What are you requesting?" : "Mitä pyydät?",
+    "Request subject" : "Pyynnön aihe",
+    "Birthday party photos, History assignment…" : "Syntymäpäiväkuvia, historiantehtäviä…",
+    "Where should these files go?" : "Mihin nämä tiedostot kuuluvat?",
+    "Upload destination" : "Lähetyksen kohde",
+    "The uploaded files are visible only to you unless you choose to share them." : "Lähetetyt tiedostot ovat vain sinulle näkyvissä, ellet päätä jakaa niitä.",
+    "Add a note" : "Lisää muistiinpano",
     "Close" : "Sulje",
     "Error creating the share: {errorMessage}" : "Virhe luotaessa jakoa: {errorMessage}",
     "Error creating the share" : "Virhe jakoa luotaessa",
@@ -113,6 +130,7 @@ OC.L10N.register(
     "Set default folder for accepted shares" : "Aseta oletuskansio hyväksytyille jaoille",
     "Reset" : "Palauta",
     "Reset folder to system default" : "Palauta kansio järjestelmän oletukseksi",
+    "Share expiration: " : "Jaon vanhentuminen:",
     "group" : "ryhmä",
     "conversation" : "keskustelu",
     "remote" : "etä",
@@ -166,8 +184,10 @@ OC.L10N.register(
     "on {server}" : "palvelimella {server}",
     "Note:" : "Huomioi:",
     "File drop" : "Tiedoston pudotus",
+    "Upload files to {foldername}." : "Lähetä tiedostot kansioon {foldername}.",
+    "By uploading files, you agree to the terms of service." : "Lähettämällä tiedostot hyväksyt käyttöehdot.",
+    "View terms of service" : "Näytä käyttöehdot",
     "Terms of service" : "Käyttöehdot",
-    "Nickname" : "Nimimerkki",
     "Share with {userName}" : "Jaa käyttäjän {userName} kanssa",
     "Share with group" : "Jaa ryhmän kanssa",
     "Share in conversation" : "Jaa keskustelussa",
@@ -180,10 +200,13 @@ OC.L10N.register(
     "Edit" : "Muokkaa",
     "Share" : "Jaa",
     "Delete" : "Poista",
+    "Password field cannot be empty" : "Salasanakenttä ei voi olla tyhjä",
+    "Replace current password" : "Korvaa nykyinen salasana",
     "Allow upload and editing" : "Salli lähetys ja muokkaus",
     "Allow editing" : "Salli muokkaus",
     "Advanced settings" : "Lisäasetukset",
     "Share label" : "Jaon nimi",
+    "Generating…" : "Luodaan…",
     "Set password" : "Aseta salasana",
     "Password expires {passwordExpirationTime}" : "Salasana vanhenee {passwordExpirationTime}",
     "Password expired" : "Salasana vanheni",
@@ -214,8 +237,12 @@ OC.L10N.register(
     "Shared multiple times with different people" : "Jaettu useita kertoja eri ihmisten kanssa",
     "Show sharing options" : "Näytä jakamisen valinnat",
     "Shared with others" : "Jaettu muiden kanssa",
+    "Upload files to {foldername}" : "Lähetä tiedostot kansioon {foldername}",
+    "Public file share" : "Julkinen tiedostojako",
+    "Publicly shared file." : "Tiedosto jaettu julkisesti.",
     "No file" : "Ei tiedostoa",
     "Public share" : "Julkinen jako",
+    "No files" : "Ei tiedostoja",
     "Overview of shared files." : "Yleisnäkymä jaetuista tiedostoista.",
     "No shares" : "Ei jakoja",
     "Files and folders you shared or have been shared with you will show up here" : "Tiedostot ja kansiot, jotka olet jakanut tai jotka on jaettu kanssasi, näkyvät täällä",
@@ -240,6 +267,9 @@ OC.L10N.register(
     "Error updating the share" : "Virhe jakoa päivittäessä",
     "File \"{path}\" has been unshared" : "Tiedoston \"{path}\" jakaminen on lopetettu",
     "Folder \"{path}\" has been unshared" : "Kansion \"{path}\" jakaminen on lopetettu",
+    "Share saved" : "Jako tallennettu",
+    "Upload files to {folder}" : "Lähetä tiedostot kansioon {folder}",
+    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} jakoi kansion kanssasi.",
     "Shared by" : "Jakanut",
     "Shared with" : "Jaettu",
     "Password created successfully" : "Salasana luotu onnistuneesti",
@@ -251,6 +281,7 @@ OC.L10N.register(
     "Show list view" : "Näytä listanäkymä",
     "Show grid view" : "Näytä ruudukkonäkymä",
     "Upload files to %s" : "Lähetä tiedostoja käyttäjälle %s",
+    "%s shared a folder with you." : "%s jakoi kansion kanssasi.",
     "Note" : "Huomio",
     "Select or drop files" : "Valitse tai pudota tiedostoja",
     "Uploading files" : "Lähetetään tiedostoja",
@@ -268,11 +299,11 @@ OC.L10N.register(
     "No compatible server found at {remote}" : "Yhteensopivaa palvelinta ei löytynyt osoitteesta {remote}",
     "Invalid server URL" : "Virheellinen palvelimen URL",
     "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
-    "Files" : "Tiedostot",
     "Download all files" : "Lataa kaikki tiedostot",
     "Search for share recipients" : "Etsi jaon vastaanottajia",
     "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
-    "Allow download" : "Salli lataus",
-    "Enter your name" : "Kirjoita nimesi"
+    "Enter your name" : "Kirjoita nimesi",
+    "Name" : "Nimi",
+    "Filename must not be empty." : "Tiedostonimi ei voi olla tyhjä."
 },
 "nplurals=2; plural=(n != 1);");
