@@ -52,15 +52,17 @@ OC.L10N.register(
     "No picture for this day" : "Nenhuma foto para este dia",
     "Picture taken on this day will show up here." : "Uma foto tirada neste dia aparecerá aqui.",
     "More photos from this day" : "Mais fotos deste dia",
+    "_%n photos_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto não atribuída","%n fotos não atribuídas","%n fotos não atribuídas"],
     "Favorite" : "Favorito",
     "Favorite image, open the full size \"{name}\" image" : "Imagem favorita, abrir a imagem \"{name}\" em tamanho real",
     "Open the full size \"{name}\" image" : "Abrir a imagem \"{name}\" no tamanho real",
     "Select image {imageName}" : "Selecionar imagem {imageName}",
     "Open the \"{name}\" folder" : "Abrir pasta \"{name}\"",
-    "Back to {folder}" : "Voltar para {folder}",
     "Go back" : "Voltar",
-    "Share this folder" : "Compartilhar esta pasta",
+    "Date range" : "Intervalo de datas",
+    "Select a date range" : "Selecione um intervalo de datas",
+    "Select places" : "Selecione lugares",
     "Dates" : "Datas",
     "Jump to specific date in list" : "Ir para uma data específica na lista",
     "Jump to {date}" : "Ir para {date}",
@@ -86,6 +88,7 @@ OC.L10N.register(
     "Choose the folder where photos and albums are uploaded to." : "Escolha a pasta na qual as fotos e os álbuns serão carregados.",
     "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
     "Unselect all" : "Desmarcar todos",
+    "Toggle filter" : "Alternar filtro",
     "Add photos to this album" : "Adicionar fotos a este álbum",
     "Manage collaborators for this album" : "Gerenciar colaboradores para este álbum",
     "Open actions menu" : "Abrir menu de ações",
@@ -129,15 +132,16 @@ OC.L10N.register(
     "Photos with tags will show up here" : "Fotos com etiquetas serão mostradas aqui",
     "Popular tags" : "Etiquetas populares",
     "All tags" : "Todas as etiquetas",
+    "Create new album from filters" : "Criar novo álbum a partir de filtros",
     "One of the source folders does not exist" : "Uma das pastas de origem não existe",
     "Add to album" : "Adicionar a álbum",
     "Delete selection" : "Excluir seleção",
     "No photos or videos in here" : "Não há fotos ou vídeos aqui",
     "Unassigned faces" : "Rostos não atribuídos",
-    "_%n photos_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
     "Failed to fetch collection." : "Falha ao obter a coleção.",
     "Failed to fetch collections list." : "Falha ao obter a lista de coleções.",
     "Failed to fetch faces list." : "Falha ao obter a lista de rostos.",
+    "Error fetching files" : "Erro ao buscar arquivos",
     "All your media" : "Todas as suas mídias",
     "Album {title}" : "Álbum {title}",
     "Shared Albums" : "Álbuns Compartilhados",
@@ -155,6 +159,8 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "Falha ao definir o estado de favorito para {fileId}",
     "Failed to set favorite state for {fileName}" : "Falha ao definir o estado de favorito para {fileName}",
     "Could not load photos folder" : "Não foi possível carregar a pasta de fotos",
+    "Back to {folder}" : "Voltar para {folder}",
+    "Share this folder" : "Compartilhar esta pasta",
     "One of the source folders does not exists" : "Uma das pastas de origem não existe",
     "Add" : "Adicionar"
 },
