@@ -34,6 +34,8 @@ OC.L10N.register(
     "Create new album" : "建立新相簿",
     "New album" : "新相簿",
     "_%n item_::_%n photos and videos_" : ["%n 個照片與影片"],
+    "Failed to fetch collaborators list." : "擷取協作者清單失敗。",
+    "Failed to update album." : "更新相簿失敗。",
     "Add people or groups who can edit your album" : "新增可以編輯您的相簿的使用者或群組",
     "Search people or groups" : "搜尋使用者或群組",
     "No recommendations. Start typing." : "無建議。開始輸入。",
@@ -45,22 +47,22 @@ OC.L10N.register(
     "Delete the public link" : "刪除公開連結",
     "Create public link share" : "建立公開連結分享",
     "Share via public link" : "透過公開連結分享",
-    "Failed to fetch collaborators list." : "擷取協作者清單失敗。",
-    "Failed to update album." : "更新相簿失敗。",
     "This collection does not exist" : "此收藏不存在",
     "An error occurred" : "發生錯誤",
     "No picture for this day" : "這天沒有照片",
     "Picture taken on this day will show up here." : "這天拍攝的照片將會顯示在此處。",
     "More photos from this day" : "更多這天的照片",
+    "_%n photos_::_%n photos_" : ["%n 個照片"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n 個未指派的照片"],
     "Favorite" : "收藏",
-    "Select image {imageName}" : "選取圖片 {imageName}",
     "Favorite image, open the full size \"{name}\" image" : "收藏影像，開啟「{name}」的原始尺寸影像",
     "Open the full size \"{name}\" image" : "開啟「{name}」的原始尺寸影像",
+    "Select image {imageName}" : "選取圖片 {imageName}",
     "Open the \"{name}\" folder" : "開啟「{name}」資料夾",
     "Go back" : "返回",
-    "Back to {folder}" : "回到 {folder}",
-    "Share this folder" : "分享此資料夾",
+    "Date range" : "日期範圍",
+    "Select a date range" : "選取日期範圍",
+    "Select places" : "選取地點",
     "Dates" : "日曆",
     "Jump to specific date in list" : "跳到清單中的指定日期",
     "Jump to {date}" : "跳到 {date}",
@@ -70,15 +72,15 @@ OC.L10N.register(
     "_{years} year ago_::_{years} years ago_" : ["{years} 年前"],
     "Enable squared photos view" : "啟用方形照片檢視",
     "Delete source directory" : "刪除來源目錄",
+    "Pick folder" : "挑選資料夾",
+    "Select a source folder for your media" : "選取您媒體的來源資料夾",
     "All folders" : "所有資料夾",
     "Add a Photos source for the timelines" : "新增時間軸的照片來源",
     "Add folder" : "新增資料夾",
-    "Pick folder" : "挑選資料夾",
-    "Select a source folder for your media" : "選取您媒體的來源資料夾",
+    "Select the default upload location for your media" : "選取您媒體的預設上傳位置",
     "Home" : "家庭",
     "Choose default Photos upload and Albums location" : "選擇預設照片上傳與相簿位置",
     "Choose a different folder" : "選擇其他資料夾",
-    "Select the default upload location for your media" : "選取您媒體的預設上傳位置",
     "View" : "檢視",
     "Media folders" : "媒體資料夾",
     "Choose the folders from where photos and videos are shown." : "選擇顯示照片與影片的資料夾。",
@@ -86,6 +88,7 @@ OC.L10N.register(
     "Choose the folder where photos and albums are uploaded to." : "選擇照片與相簿上傳到的資料夾。",
     "_%n photo_::_%n photos_" : ["%n 張照片"],
     "Unselect all" : "取消全選",
+    "Toggle filter" : "切換篩選器",
     "Add photos to this album" : "新增照片至此相簿",
     "Manage collaborators for this album" : "管理此相簿的協作者",
     "Open actions menu" : "開啟動作選單",
@@ -122,22 +125,23 @@ OC.L10N.register(
     "Add photos to this place" : "新增照片至此處",
     "Cover photo for place {placeName}" : "地點 {placeName} 的封面照片",
     "There is no place yet!" : "還沒有地點！",
-    "Cover photo for shared album {albumName}." : "共享相簿 {albumName}. 的封面照片",
+    "Cover photo for shared album {albumName}" : "共享相簿 {albumName} 的封面照片",
     "Back to tags overview" : "回到標籤概覽",
     "No photos with this tag yet" : "還沒有帶有此標籤的照片",
     "No tags yet" : "尚未加入標籤",
     "Photos with tags will show up here" : "此處會顯示圖片的標籤",
     "Popular tags" : "熱門標籤",
     "All tags" : "全部標籤",
+    "Create new album from filters" : "從篩選條件建立新相簿",
     "One of the source folders does not exist" : "其中一個來源資料夾不存在",
     "Add to album" : "新增至相簿",
     "Delete selection" : "刪除選擇",
     "No photos or videos in here" : "此處沒有照片或影片",
     "Unassigned faces" : "未指派的臉孔",
-    "_%n photos_::_%n photos_" : ["%n 個照片"],
     "Failed to fetch collection." : "擷取收藏品失敗。",
     "Failed to fetch collections list." : "擷取收藏清單失敗。",
     "Failed to fetch faces list." : "擷取臉部清單失敗。",
+    "Error fetching files" : "擷取檔案時發生錯誤",
     "All your media" : "您所有的媒體",
     "Album {title}" : "相簿 {title}",
     "Shared Albums" : "已分享的相簿",
@@ -148,13 +152,15 @@ OC.L10N.register(
     "{title}'s face" : "{title} 的臉",
     "{startDate} to {endDate}" : "{startDate} 到 {endDate}",
     "Details" : "詳細資訊",
-    "Failed to rename {oldName} to {faceName}." : "重新命名 {oldName} 為 {faceName} 失敗。",
-    "Failed to delete {faceName}." : "刪除 {faceName} 失敗。",
-    "Failed to delete {fileId}." : "刪除 {fileId} 失敗。",
-    "Failed to delete {fileName}." : "刪除 {fileName} 失敗。",
-    "Failed to set favorite state for {fileId}." : "未能為 {fileId} 設定最愛狀態。",
-    "Failed to set favorite state for {fileName}." : "未能為 {fileName} 設定最愛狀態。",
+    "Failed to rename {oldName} to {faceName}" : "無法將 {oldName} 重新命名為 {faceName}",
+    "Failed to delete {faceName}" : "刪除 {faceName} 失敗",
+    "Failed to delete {fileId}" : "刪除 {fileId} 失敗",
+    "Failed to delete {fileName}" : "刪除 {fileName} 失敗",
+    "Failed to set favorite state for {fileId}" : "無法設定 {fileId} 的收藏狀態",
+    "Failed to set favorite state for {fileName}" : "無法設定 {fileName} 的收藏狀態",
     "Could not load photos folder" : "無法載入照片資料夾",
+    "Back to {folder}" : "回到 {folder}",
+    "Share this folder" : "分享此資料夾",
     "One of the source folders does not exists" : "其中一個來源資料夾不存在",
     "Add" : "新增"
 },
