@@ -2,11 +2,11 @@ OC.L10N.register(
     "serverinfo",
     {
     "CPU info not available" : "اطلاعات CPU در دسترس نیست",
-    "Load average: {cpu} (last minute)" : "Load average: {cpu} (last minute)",
     "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}",
     "RAM info not available" : "RAM info not available",
     "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}",
     "SWAP info not available" : "SWAP info not available",
+    "Copied!" : "رونوشت شد!",
     "Not supported!" : "پشتیبانی وجود ندارد!",
     "Press ⌘-C to copy." : "برای کپی کردن از دکمه های C+⌘ استفاده نمایید",
     "Press Ctrl-C to copy." : "برای کپی کردن از دکمه ctrl+c استفاده نمایید",
@@ -34,7 +34,6 @@ OC.L10N.register(
     "Free Space:" : "فضای خالی:",
     "Network" : "شبکه",
     "Hostname:" : "Hostname:",
-    "DNS:" : "DNS:",
     "Gateway:" : "Gateway:",
     "Status:" : "Status:",
     "Speed:" : "Speed:",
@@ -43,10 +42,7 @@ OC.L10N.register(
     "IPv4:" : "IPv4:",
     "IPv6:" : "IPv6:",
     "Active users" : "کاربران فعال",
-    "Total users:" : "تعداد کل کاربران:",
-    "24 hours:" : "24 hours:",
-    "1 hour:" : "1 hour:",
-    "5 mins:" : "5 mins:",
+    "Last hour" : "Last hour",
     "Shares" : "اشتراک گذاری ها",
     "Users:" : "کاربران:",
     "Groups:" : "Groups:",
@@ -67,11 +63,8 @@ OC.L10N.register(
     "Database" : "پایگاه داده",
     "Type:" : "نوع:",
     "External monitoring tool" : "ابزار نظارت خارجی",
-    "You can connect an external monitoring tool by using this end point:" : "با استفاده از این نقطه پایانی می توانید یک ابزار نظارت خارجی را به هم متصل شدن:",
     "Copy" : "کپی کردن",
-    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Appending \"?format=json\" at the end of the URL gives you the result in JSON.",
     "To use an access token, please generate one then set it using the following command:" : "To use an access token, please generate one then set it using the following command:",
-    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Then pass the token with the \"NC-Token\" header when querying the above URL.",
-    "You will get a notification once one of your disks is nearly full." : "هنگامی که یکی از دیسک های شما تقریباً کامل شد ، یک اعلان دریافت خواهید کرد."
+    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Then pass the token with the \"NC-Token\" header when querying the above URL."
 },
 "nplurals=2; plural=(n > 1);");
