@@ -119,9 +119,10 @@ OC.L10N.register(
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Omogućena je konfiguracija samo za čitanje. Time se sprječava postavljanje nekih konfiguracija putem web-sučelja. Nadalje, datoteku treba ručno prebaciti u način pisanja pri svakom ažuriranju.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vaša se baza podataka ne pokreće s razinom izolacije transakcije „READ COMMITTED”. To može uzrokovati probleme kada se paralelno izvršava više radnji.",
     "Nextcloud settings" : "Postavke Nextclouda",
+    "Enable" : "Omogući",
     "Here you can decide which group can access certain sections of the administration settings." : "Ovdje možete odlučiti koja grupa može pristupiti određenim dijelovima administratorskih postavki.",
-    "None" : "Nema",
     "Unable to modify setting" : "Nije moguće izmijeniti postavku",
+    "None" : "Nema",
     "Allow apps to use the Share API" : "Dopusti aplikacijama korištenje API-ja za dijeljenje",
     "Allow resharing" : "Dopusti ponovno dijeljenje",
     "Allow sharing with groups" : "Dopusti dijeljenje s grupama",
@@ -150,6 +151,7 @@ OC.L10N.register(
     "Featured" : "Istaknuto",
     "This app is supported via your current Nextcloud subscription." : "Aplikacija je podržana unutar vaše trenutne pretplate na Nextcloud.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Istaknute aplikacije razvijaju članovi zajednice. One nude osnovnu funkcionalnost i spremne su za produkciju.",
+    "Disable all" : "Onemogući sve",
     "Icon" : "Ikona",
     "Name" : "Naziv",
     "Version" : "Inačica",
@@ -157,13 +159,21 @@ OC.L10N.register(
     "Actions" : "Radnje",
     "Results from other categories" : "Rezultati iz drugih kategorija",
     "No apps found for your version" : "Nije pronađena nijedna aplikacija za vašu inačicu",
-    "Disable all" : "Onemogući sve",
     "_%n app has an update available_::_%n apps have an update available_" : ["Dostupno je ažuriranje za %n aplikaciju","Dostupno je ažuriranje za %n aplikacije","Dostupno je ažuriranje za %n aplikacija"],
+    "Group name" : "Naziv grupe",
+    "Loading groups…" : "Učitavanje grupa…",
     "Loading" : "Učitavanje",
     "Daemon" : "Daemon",
     "Type" : "Vrsta",
     "Display Name" : "Ime",
+    "Learn more" : "Saznajte više",
+    "Confirm" : "Potvrdi",
+    "Cancel" : "Odustani",
     "Description" : "Opis",
+    "View in store" : "Pogledajte u trgovini",
+    "Visit website" : "Posjeti web-mjesto",
+    "Admin documentation" : "Dokumentacija za administratore",
+    "Developer documentation" : "Dokumentacija za razvojne programere",
     "Details" : "Pojedinosti",
     "All" : "Sve",
     "Limit app usage to groups" : "Ograničite primjenu aplikacije na grupe",
@@ -180,59 +190,50 @@ OC.L10N.register(
     "Request feature" : "Zatražite značajku",
     "Ask questions or discuss" : "Postavljajte pitanja ili raspravljajte",
     "Rate" : "Ocijeni",
-    "View in store" : "Pogledajte u trgovini",
-    "Visit website" : "Posjeti web-mjesto",
-    "Admin documentation" : "Dokumentacija za administratore",
-    "Developer documentation" : "Dokumentacija za razvojne programere",
     "Changelog" : "Zapis promjena",
-    "Marked for remote wipe" : "Označeno za udaljeno brisanje",
-    "Device settings" : "Postavke uređaja",
-    "Allow filesystem access" : "Omogući pristup datotečnom sustavu",
-    "Rename" : "Preimenuj",
-    "Revoke" : "Opozovi",
-    "Wipe device" : "Izbriši sve s uređaja",
     "Google Chrome for Android" : "Google Chrome za Android",
     "{productName} iOS app" : "{productName} aplikacija za iOS",
     "{productName} Android app" : "{productName} aplikacija za Android",
     "{productName} Talk for iOS" : "{productName} Talk za iOS",
     "{productName} Talk for Android" : "{productName} Talk za Android",
     "This session" : "Ova sesija",
+    "Marked for remote wipe" : "Označeno za udaljeno brisanje",
+    "Device settings" : "Postavke uređaja",
+    "Allow filesystem access" : "Omogući pristup datotečnom sustavu",
+    "Rename" : "Preimenuj",
+    "Revoke" : "Opozovi",
+    "Wipe device" : "Izbriši sve s uređaja",
     "Device" : "Uređaj",
     "Last activity" : "Posljednja aktivnost",
     "Devices & sessions" : "Uređaji i sesije",
     "Web, desktop and mobile clients currently logged in to your account." : "Web, računalni i mobilni klijenti trenutno prijavljeni u vaš račun.",
+    "Error while creating device token" : "Pogreška pri stvaranju tokena za uređaj",
     "App name" : "Naziv aplikacije",
     "Create new app password" : "Stvori novu zaporku za aplikaciju",
-    "Error while creating device token" : "Pogreška pri stvaranju tokena za uređaj",
+    "Could not copy app password. Please copy it manually." : "Kopiranje zaporke aplikacije nije uspjelo. Kopirajte je ručno.",
     "Login" : "Prijava",
     "Password" : "Zaporka",
     "Show QR code for mobile apps" : "Prikaži QR kôd za mobilne aplikacije",
-    "Could not copy app password. Please copy it manually." : "Kopiranje zaporke aplikacije nije uspjelo. Kopirajte je ručno.",
     "Use system cron service to call the cron.php file every 5 minutes." : "Koristite se sistemskim servisom cron za pozivanje datoteke cron.php svakih 5 minuta.",
     "Profile" : "Profil",
-    "Enable" : "Omogući",
     "Server-side encryption" : "Šifriranje na poslužitelju",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifriranje na poslužitelju omogućuje šifriranje datoteka koje su otpremljene na ovaj poslužitelj. Ovaj postupak može narušiti performanse sustava pa ga omogućite samo ako je potrebno.",
     "Enable server-side encryption" : "Omogući šifriranje na poslužitelju",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Nije učitan modul za šifriranje, omogućite modul za šifriranje u izborniku aplikacije.",
+    "Select default encryption module:" : "Odaberi zadani modul za šifriranje:",
+    "Enable encryption" : "Omogući šifriranje",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Ako je šifriranje na poslužitelju omogućeno, sve datoteke koje se od tog trenutka otpreme na poslužitelj bit će šifrirane u stanju mirovanja na poslužitelju. Kasnije možete onemogućiti šifriranje ako aktivni modul za šifriranje podržava tu funkciju i ispunjeni su svi preduvjeti (npr. postavljanje ključa za oporavak).",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifriranje samo po sebi ne jamči sigurnost sustava. Pogledajte dokumentaciju za više informacija o načinu rada aplikacije za šifriranje i slučajevima korištenja.",
     "Be aware that encryption always increases the file size." : "Imajte na umu da šifriranje uvijek povećava veličinu datoteke.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Uvijek je dobra ideja redovito izrađivati sigurnosne kopije podataka; ako upotrebljavate šifriranje, obavezno sigurnosno kopirajte ključeve za šifriranje zajedno sa svojim podacima.",
     "This is the final warning: Do you really want to enable encryption?" : "Ovo je posljednje upozorenje: želite li zaista omogućiti šifriranje?",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "Nije učitan modul za šifriranje, omogućite modul za šifriranje u izborniku aplikacije.",
-    "Select default encryption module:" : "Odaberi zadani modul za šifriranje:",
-    "Cancel" : "Odustani",
-    "Confirm" : "Potvrdi",
     "Submit" : "Šalji",
-    "Remove group" : "Ukloni grupu",
     "Current password" : "Trenutna zaporka",
     "New password" : "Nova zaporka",
     "Change password" : "Promijeni zaporku",
     "Picture provided by original account" : "Slika s izvornog računa",
-    "Your biography" : "Vaša biografija",
     "You are a member of the following groups:" : "Član ste sljedećih grupa:",
     "Your full name" : "Vaše ime i prezime",
-    "Primary email for password reset and notifications" : "Primarna e-pošta za resetiranje zaporke i primanje obavijesti",
     "Email options" : "Mogućnosti e-pošte",
     "Remove primary email" : "Ukloni primarnu adresu e-pošte",
     "Delete email" : "Izbriši adresu e-pošte",
@@ -245,10 +246,11 @@ OC.L10N.register(
     "Unable to add additional email address" : "Nije moguće dodati dodatnu adresu e-pošte",
     "Unable to update additional email address" : "Nije moguće ažurirati dodatnu adresu e-pošte",
     "Unable to delete additional email address" : "Nije moguće izbrisati dodatnu adresu e-pošte",
+    "Primary email for password reset and notifications" : "Primarna e-pošta za resetiranje zaporke i primanje obavijesti",
     "No email address set" : "Nije postavljena adresa e-pošte",
     "Your headline" : "Vaš naslov",
-    "Help translate" : "Pomozite prevesti",
     "Unable to update language" : "Nije moguće ažurirati jezik",
+    "Help translate" : "Pomozite prevesti",
     "No language set" : "Nije postavljen jezik",
     "Your organisation" : "Vaša organizacija",
     "Your phone number" : "Vaš broj telefona",
@@ -294,11 +296,11 @@ OC.L10N.register(
     "Send email" : "Pošalji poruku e-pošte",
     "Default quota" : "Zadana kvota",
     "Select default quota" : "Odaberi zadanu kvotu",
+    "Server error while trying to complete WebAuthn device registration" : "Pogreška poslužitelja tijekom dovršavanja registracije WebAuthn uređaja",
     "Passwordless authentication requires a secure connection." : "Autentifikacija bez zaporke zahtijeva sigurnu vezu.",
     "Add WebAuthn device" : "Dodaj WebAuthn uređaj",
     "Please authorize your WebAuthn device." : "Autorizirajte svoj WebAuthn uređaj.",
     "Adding your device …" : "Dodavanje uređaja...",
-    "Server error while trying to complete WebAuthn device registration" : "Pogreška poslužitelja tijekom dovršavanja registracije WebAuthn uređaja",
     "Unnamed device" : "Neimenovani uređaj",
     "Passwordless Authentication" : "Autentifikacija bez zaporke",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Omogućite korištenje autentifikacije bez zaporke na svom računu u skladu sa standardom FIDO2.",
@@ -308,7 +310,6 @@ OC.L10N.register(
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Administrator možete detaljnije podešavati dijeljenja. Pogledajte odgovarajuću dokumentaciju za više informacija.",
     "You need to enable the File sharing App." : "Morate omogućiti aplikaciju za dijeljenje datoteka.",
     "Admins" : "Administratori",
-    "Group name" : "Naziv grupe",
     "Sending…" : "Slanje…",
     "Email sent" : "E-pošta je poslana",
     "Location" : "Lokacija",
@@ -336,6 +337,7 @@ OC.L10N.register(
     "Disable" : "Onemogući",
     "The app will be downloaded from the App Store" : "Aplikacija će se preuzeti iz trgovine aplikacijama",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ova aplikacija nije označena kao kompatibilna s vašom inačicom Nextclouda. Ako odlučite nastaviti, moći ćete instalirati aplikaciju. Imajte na umu da aplikacija možda neće raditi kako očekujete.",
+    "Unknown" : "Nepoznata pogreška",
     "Never" : "Nikad",
     "Error: This app cannot be enabled because it makes the server unstable" : "Pogreška: ova aplikacija ne može biti omogućena jer čini poslužitelj nestabilnim",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacija je omogućena, ali je treba ažurirati. Za 5 sekundi bit ćete preusmjereni na stranicu za ažuriranje.",
@@ -380,43 +382,7 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ovo izdanje Nextclouda nije podržano i nisu dostupne trenutne obavijesti.",
     "Use a second factor besides your password to increase security for your account." : "Koristite se i drugim faktorom pored zaporke kako biste povećali sigurnost svog računa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ako se za povezivanje s Nextcloudom koristite aplikacijama treće strane, stvorite i konfigurirajte lozinku za svaku aplikaciju prije omogućavanja drugog faktora za provođenje autentifikacije.",
-    "No user supplied" : "Nijedan korisnik nije podnesen",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Unesite administratorsku zaporku za oporavak; u protivnom će svi podaci korisnika biti izgubljeni.",
-    "Invalid user" : "Nevažeći korisnik",
-    "Your username is: %s" : "Vaše korisničko ime je: %s",
-    "Logged in user must be a subadmin" : "Korisnik koji je prijavljen mora biti podadministrator",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Na čekanju je pozadinski zadatak za provjeravanje vjerodajnica SSL-a koje uvezu korisnici. Provjerite ponovno kasnije.",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Prisutne su vjerodajnice SSL-a koje su uvezli korisnici i koje Nextcloud 21 ne upotrebljava. Mogu se uvesti putem naredbenog retka s pomoću naredbe „occ security:certificates:import”. U nastavku su prikazani njihovi putovi unutar podatkovnog direktorija.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "U bazi podataka nedostaju određeni indeksi. Zbog činjenice da bi dodavanje indeksa u velikim tablicama moglo potrajati neko duže vrijeme, isti se ne dodaju automatski. Izvršenjem „occ db:add-missing-indices” se ti indeksi mogu ručno dodati dok instanca radi. Kada se indeksi dodaju, upiti u te tablice obično su mnogo brži.",
-    "Exclude groups from sharing" : "Izuzmi grupe iz dijeljenja",
-    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe još uvijek moći primati dijeljene sadržaje, ali ih neće moći pokrenuti.",
     "Set default expiration date for shares" : "Postavi zadani datum isteka dijeljenja",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvofaktorska autentifikacija može se primijeniti na sve korisnike i određene grupe. Ako nisu konfigurirali davatelje usluge dvofaktorske autentifikacije, neće se moći prijaviti u sustav.",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Nakon odabira grupa koje će biti obuhvaćene/izuzete, primjenjuje se sljedeća logika za utvrđivanje je li 2FA omogućen za određenog korisnika: ako nije odabrana nijedna grupa, 2FA je omogućen za sve osim za članove izuzetih grupa. Ako su odabrane određene grupe, 2FA je omogućen samo za sve članove tih grupa. Ako je korisnik član odabrane i izuzete grupe, odabrana grupa ima prednost i 2FA se primjenjuje.",
-    "{license}-licensed" : "Licencirano prema {license}",
-    "Username" : "Korisničko ime",
-    "Additional emails" : "Dodatne adrese e-pošte",
-    "Enable Profile" : "Omogući profil",
-    "New user" : "Novi korisnik",
-    "User backend" : "Korisnički pozadinski sustav",
-    "You do not have permissions to see the details of this user" : "Nemate dopuštenja za prikaz pojedinosti ovog korisnika",
-    "Add user to group" : "Dodaj korisnika u grupu",
-    "Set user as admin for" : "Postavi korisnika kao administratora za",
-    "Select user quota" : "Odaberi kvotu korisnika",
-    "Delete user" : "Izbriši korisnika",
-    "Wipe all devices" : "Izbriši podatke sa svih uređaja",
-    "Disable user" : "Onemogući korisnika",
-    "Enable user" : "Omogući korisnika",
-    "Toggle user actions menu" : "Uklj./isklj. izbornik s radnjama korisnika",
-    "Show user backend" : "Prikaži korisnički pozadinski sustav",
-    "Name your device" : "Dodijelite naziv svom uređaju",
-    "Server error while trying to add WebAuthn device" : "Pogreška poslužitelja pri dodavanju WebAuthn uređaja",
-    "by {author}\n{license}" : "{author}\n{license}",
-    "Active users" : "Aktivni korisnici",
-    "Disabled users" : "Onemogućeni korisnici",
-    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Nije dostupno jer nije dopušteno objavljivanje korisničkih podataka na poslužitelju pretraživanja, obratite se administratoru sustava ako imate pitanja",
-    "Show to logged in users only" : "Prikaži samo prijavljenim korisnicima",
-    "SMTP Username" : "Korisničko ime za SMTP",
-    "Follow us on Twitter" : "Pratite nas na Twitteru"
+    "Your biography" : "Vaša biografija"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
