@@ -1,10 +1,6 @@
 OC.L10N.register(
     "systemtags",
     {
-    "Tag name is empty" : "Merkelapp er tom",
-    "Update" : "Oppdater",
-    "Create" : "Opprett",
-    "Select tag …" : "Velg merkelapp…",
     "System tag %1$s added by the system" : "Systemmerkelappen %1$s ble lagt til av systemet",
     "Added system tag {systemtag}" : "La til system-merkelapp {systemtag}",
     "Added system tag %1$s" : "La til system-merkelapp %1$s",
@@ -42,27 +38,63 @@ OC.L10N.register(
     "%s (restricted)" : "%s (begrenset)",
     "%s (invisible)" : "%s (usynlig)",
     "<strong>System tags</strong> for a file have been modified" : "Endringer av en fils <strong>System-merkelapper</strong>",
+    "Files" : "Filer",
     "Tags" : "Merkelapper",
     "All tagged %s …" : "Alle merket med %s…",
     "tagged %s" : "merket %s",
     "Collaborative tags" : "Samarbeidsmerkelapper",
-    "Collaborative tagging functionality which shares tags among users." : "Samarbeidsmerkelapp-funksjonalitet som deler merkelapper mellom brukere.",
-    "No tags found" : "Fant ingen merkelapper",
-    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samarbeidsmerkelapper er tilgjengelige for alle brukere. Begrensede merkelapper er synlige for brukere, men kan ikke tildeles av dem. Usynlige merkelapper er for intern bruk, siden brukere ikke kan se eller tildele dem.",
-    "Create a new tag" : "Lag en ny merkelapp",
-    "Name" : "Navn",
+    "Collaborative tagging functionality which shares tags among people." : "Samarbeidsmerkelapp-funksjonalitet som deler merkelapper mellom brukere.",
+    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samarbeidsmerkelapp-funksjonalitet som deler merkelapper mellom brukere. Flott for team.\n\t(Hvis du er en leverandør med en installasjon av flere leieforhold, anbefales det å deaktivere denne appen ettersom merkelapper deles.)",
     "Public" : "Offentlig",
     "Restricted" : "Begrenset",
     "Invisible" : "Usynlig",
+    "Created tag" : "Opprettet merkelapp",
+    "Failed to create tag" : "Oppretting av merkelapp feilet",
+    "Updated tag" : "Merkelapp oppdatert",
+    "Failed to update tag" : "Oppdatering av merkelapp feilet",
+    "Deleted tag" : "Slettet merkelappen",
+    "Failed to delete tag" : "Sletting av merkelapp feilet",
+    "Create or edit tags" : "Opprett eller rediger merkelapper",
+    "Search for a tag to edit" : "Søk etter en merkelapp å redigere",
+    "Collaborative tags …" : "Samarbeidende merkelapper...",
+    "No tags to select" : "Ingen merkelapper å velge",
+    "Tag name" : "Navn på merkelapp",
+    "Tag level" : "Nivå på merkelapp",
+    "Create" : "Opprett",
+    "Update" : "Oppdater",
     "Delete" : "Slett",
     "Reset" : "Tilbakestill",
-    "No files in here" : "Ingen filer her",
-    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
-    "Size" : "Størrelse",
-    "Modified" : "Endret",
-    "Tagged files" : "Filer med merkelapper",
-    "Select tags to filter by" : "Velg merkelapper å filtrere etter",
-    "Please select tags to filter by" : "Velg merkelapper å filtrere etter",
-    "No files found for the selected tags" : "Ingen filer funnet for de valgte merkelappene"
+    "Loading …" : "Laster ...",
+    "{displayName} (hidden)" : "{displayName} (skjult)",
+    "{displayName} (restricted)" : "{displayName} (begrenset tilgang)",
+    "Failed to apply tags changes" : "Kunne ikke utføre endring av merkelapper",
+    "File tags modification canceled" : "Endring av merkelapper for fil ble avbrutt",
+    "Manage tags" : "Håndtere etiketter",
+    "Applying tags changes…" : "Utfører endring av merkelapper…",
+    "Search or create tag" : "Søk etter eller opprett merkelapp",
+    "Change tag color" : "Endre farge på merkelapp",
+    "Create new tag" : "Opprett ny merkelapp",
+    "Select or create tags to apply to all selected files" : "Velg eller opprett merkelapp for alle valgte filer",
+    "Cancel" : "Avbryt",
+    "Apply changes" : "Utfør endringer",
+    "Failed to load tags" : "Lasting av merkelapper feilet",
+    "Failed to load selected tags" : "Lasting av valgte merkelapper feilet",
+    "Failed to select tag" : "Utvelging av merkelapp feilet",
+    "Loading collaborative tags …" : "Laster samarbeidende merkelapper...",
+    "Search or create collaborative tags" : "Søk etter eller opprett samarbeidende merkelapper",
+    "No tags to select, type to create a new tag" : "Ingen merkelapper å velge, skriv for å opprette en ny merkelapp",
+    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samarbeidsmerkelapper er tilgjengelige for alle brukere. Begrensede merkelapper er synlige for brukere, men kan ikke tildeles av dem. Usynlige merkelapper er for intern bruk, siden brukere ikke kan se eller tildele dem.",
+    "Assigned collaborative tags" : "Tildelt samarbeidstagger",
+    "Open in Files" : "Åpne i Filer",
+    "List of tags and their associated files and folders." : "Liste over merkelapper og deres assosierte filer og mapper.",
+    "No tags found" : "Fant ingen merkelapper",
+    "Tags you have created will show up here." : "Merkelapper du har opprettet, vil vises her.",
+    "Failed to load tag" : "Kunne ikke laste merkelapp",
+    "Failed to load last used tags" : "Lasting av sist brukte merkelapper feilet",
+    "Missing \"Content-Location\" header" : "Mangler \"Innhold-Plassering\"-overskrift",
+    "A tag with the same name already exists" : "En merkelapp med det navnet finnes allerede",
+    "Failed to load tags for file" : "Lasting av merkelapper for filen feilet",
+    "Failed to set tag for file" : "Kunne ikke angi merkelapp for fil",
+    "Failed to delete tag for file" : "Sletting av merkelappen for filen feilet"
 },
 "nplurals=2; plural=(n != 1);");
