@@ -27,6 +27,7 @@ OC.L10N.register(
     "Could not complete login" : "ログインが完了できませんでした",
     "State token missing" : "状態トークンがありません",
     "Your login token is invalid or has expired" : "あなたのログイントークンは無効か期限が切れています。",
+    "Please use original client" : "オリジナルのクライアントをご利用ください",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "コミュニティリリースのNextcloudにサポートはなく、プッシュ通知には制限があります",
     "Login" : "ログイン",
     "Unsupported email length (>255)" : "メールアドレスが長すぎます (>255)",
@@ -43,6 +44,7 @@ OC.L10N.register(
     "Task not found" : "タスクは見つかりません",
     "Internal error" : "内部エラー",
     "Not found" : "見つかりませんでした",
+    "Node is locked" : "ノードがロックされています",
     "Bad request" : "Bad request",
     "Requested task type does not exist" : "要求されたタスクの種類が存在しません",
     "Necessary language model provider is not available" : "必要な言語モデルプロバイダーが利用できません",
@@ -51,6 +53,11 @@ OC.L10N.register(
     "No translation provider available" : "利用可能な翻訳プロバイダーがありません",
     "Could not detect language" : "言語を検出できませんでした",
     "Unable to translate" : "翻訳できませんでした",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "修復ステップ:",
+    "Repair info:" : "修復情報:",
+    "Repair warning:" : "修復警告:",
+    "Repair error:" : "修復エラー:",
     "Nextcloud Server" : "Nextcloud サーバー",
     "Some of your link shares have been removed" : "リンク共有の一部が削除されました",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "セキュリティ上の不具合により、あなたのリンク共有をいくつか削除する必要がありました。 詳しくはリンクをご覧ください。",
@@ -58,11 +65,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "support app にサブスクリプションキーを入力して、アカウント数の上限を増やすことができます。これにより、Nextcloud Enterprise が提供するすべての追加特典が付与され、企業での運用には非常におすすめです。",
     "Learn more ↗" : "もっと詳しく知る",
     "Preparing update" : "アップデートの準備中",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "修復ステップ:",
-    "Repair info:" : "修復情報:",
-    "Repair warning:" : "修復警告:",
-    "Repair error:" : "修復エラー:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "config.phpでブラウザ経由でのアップデートが無効になっていますので、コマンドラインアップデーターをご利用ください。",
     "Turned on maintenance mode" : "メンテナンスモードがオンになりました",
     "Turned off maintenance mode" : "メンテナンスモードがオフになりました",
@@ -79,6 +81,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (非互換)",
     "The following apps have been disabled: %s" : "次のアプリが無効になりました: %s ",
     "Already up to date" : "すべて更新済",
+    "Windows Command Script" : "Windowsコマンドスクリプト",
+    "Electronic book document" : "電子書籍ドキュメント",
+    "TrueType Font Collection" : "TrueTypeフォントコレクション",
+    "Web Open Font Format" : "Webオープンフォント形式",
+    "GPX geographic data" : "GPX地理データ",
+    "Gzip archive" : "Gzipアーカイブ",
+    "Adobe Illustrator document" : "Adobe Illustratorドキュメント",
+    "Java source code" : "Javaソースコード",
+    "JavaScript source code" : "JavaScriptソースコード",
+    "JSON document" : "JSONドキュメント",
+    "Microsoft Access database" : "Microsoft Accessデータベース",
+    "Microsoft OneNote document" : "Microsoft OneNoteドキュメント",
+    "Microsoft Word document" : "Microsoft Wordドキュメント",
+    "Unknown" : "不明",
+    "PDF document" : "PDFドキュメント",
+    "PostScript document" : "PostScriptドキュメント",
+    "RSS summary" : "RSS概要",
+    "Android package" : "Androidパッケージ",
+    "KML geographic data" : "KML地理データ",
+    "KML geographic compressed data" : "KML地理圧縮データ",
+    "Lotus Word Pro document" : "Lotus Word Proドキュメント",
+    "Excel spreadsheet" : "Excelスプレッドシート",
+    "Excel add-in" : "Excelアドイン",
+    "Excel 2007 binary spreadsheet" : "Excel 2007バイナリスプレッドシート",
+    "Excel spreadsheet template" : "Excelスプレッドシートテンプレート",
+    "Outlook Message" : "Outlookメッセージ",
+    "PowerPoint presentation" : "PowerPointプレゼンテーション",
+    "PowerPoint add-in" : "PowerPointアドイン",
+    "PowerPoint presentation template" : "PowerPointプレゼンテーションテンプレート",
+    "Word document" : "Wordドキュメント",
+    "ODF formula" : "ODFフォーミュラ",
+    "ODG drawing" : "ODG図面",
+    "ODG drawing (Flat XML)" : "ODG 図面 (フラット XML)",
+    "ODG template" : "ODGテンプレート",
+    "ODP presentation" : "ODPプレゼンテーション",
+    "ODP presentation (Flat XML)" : "ODPプレゼンテーション (フラット XML)",
+    "ODP template" : "ODPテンプレート",
+    "ODS spreadsheet" : "ODSスプレッドシート",
+    "ODS spreadsheet (Flat XML)" : "ODSスプレッドシート (フラット XML)",
+    "ODS template" : "ODSテンプレート",
+    "ODT document" : "ODTドキュメント",
+    "ODT document (Flat XML)" : "ODTドキュメント (フラット XML)",
+    "ODT template" : "ODTテンプレート",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007プレゼンテーション",
+    "PowerPoint 2007 show" : "PowerPoint 2007 表示",
+    "PowerPoint 2007 presentation template" : "PowerPoint　2007プレゼンテーションテンプレート",
+    "Excel 2007 spreadsheet" : "Excel 2007スプレッドシート",
+    "Excel 2007 spreadsheet template" : "Excel 2007スプレッドシートテンプレート",
+    "Word 2007 document" : "Word 2007ドキュメント",
+    "Word 2007 document template" : "Word 2007ドキュメントテンプレート",
+    "Microsoft Visio document" : "Microsoft Visioドキュメント",
+    "WordPerfect document" : "WordPerfectドキュメント",
+    "7-zip archive" : "7-zipアーカイブ",
+    "Blender scene" : "Blenderシーン",
+    "Bzip2 archive" : "Bzip2アーカイブ",
+    "Debian package" : "Debianパッケージ",
+    "FictionBook document" : "FictionBookドキュメント",
+    "Unknown font" : "不明なフォント",
+    "Krita document" : "Kritaドキュメント",
+    "Mobipocket e-book" : "Mobipocket 電子書籍",
+    "Windows Installer package" : "Windowsインストーラーパッケージ",
+    "Perl script" : "Perlスクリプト",
+    "PHP script" : "PHPスクリプト",
+    "Tar archive" : "Tarアーカイブ",
+    "XML document" : "XMLドキュメント",
+    "YAML document" : "YAMLドキュメント",
+    "Zip archive" : "Zipアーカイブ",
+    "Zstandard archive" : "Zstandardアーカイブ",
+    "AAC audio" : "AAC音声",
+    "FLAC audio" : "FLAC音声",
+    "MPEG-4 audio" : "MPEG-4音声",
+    "MP3 audio" : "MP3音声",
+    "Ogg audio" : "Ogg音声",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVeスタンダード音声",
+    "WebM audio" : "WebM音声",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCastプレイリスト",
+    "Windows BMP image" : "Windows BMP画像",
+    "Better Portable Graphics image" : "Better Portable Graphics画像",
+    "EMF image" : "EMF画像",
+    "GIF image" : "GIF画像",
+    "HEIC image" : "HEIC画像",
+    "HEIF image" : "HEIF画像",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2画像",
+    "JPEG image" : "JPEG画像",
+    "PNG image" : "PNG画像",
+    "SVG image" : "SVG画像",
+    "Truevision Targa image" : "Truevision Targa画像",
+    "TIFF image" : "TIFF画像",
+    "WebP image" : "WebP画像",
+    "Digital raw image" : "Digital raw画像",
+    "Windows Icon" : "Windowsアイコン",
+    "Email message" : "メールメッセージ",
+    "VCS/ICS calendar" : "VCS/ICSカレンダー",
+    "CSS stylesheet" : "CSSスタイルシート",
+    "CSV document" : "CSVドキュメント",
+    "HTML document" : "HTMLドキュメント",
+    "Markdown document" : "Markdownドキュメント",
+    "Org-mode file" : "Org-modeファイル",
+    "Plain text document" : "プレーンテキストドキュメント",
+    "Rich Text document" : "リッチテキストドキュメント",
+    "Electronic business card" : "電子ビジネスカード",
+    "C++ source code" : "C++ソースコード",
+    "LDIF address book" : "LDIFアドレス帳",
+    "NFO document" : "NFOドキュメント",
+    "PHP source" : "PHPソース",
+    "Python script" : "Pythonスクリプト",
+    "ReStructuredText document" : "ReStructuredTextドキュメント",
+    "3GPP multimedia file" : "3GPPマルチメディアファイル",
+    "MPEG video" : "MPEGビデオ",
+    "DV video" : "DVビデオ",
+    "MPEG-2 transport stream" : "MPEG-2トランスポートストリーム",
+    "MPEG-4 video" : "MPEG-4ビデオ",
+    "Ogg video" : "Oggビデオ",
+    "QuickTime video" : "QuickTimeビデオ",
+    "WebM video" : "WebMビデオ",
+    "Flash video" : "Flashビデオ",
+    "Matroska video" : "Matroskaビデオ",
+    "Windows Media video" : "Windows Mediaビデオ",
+    "AVI video" : "AVI ビデオ",
     "Error occurred while checking server setup" : "サーバー設定のチェック中にエラーが発生しました",
     "For more details see the {linkstart}documentation ↗{linkend}." : "詳細については、{linkstart}ドキュメント↗{linkend}を参照してください。",
     "unknown text" : "不明なテキスト",
@@ -131,7 +252,7 @@ OC.L10N.register(
     "Places" : "場所",
     "Date" : "日付",
     "Search people" : "人物を検索",
-    "People" : "人間",
+    "People" : "ユーザー",
     "Filter in current view" : "現在のビューでフィルタ",
     "Results" : "結果",
     "Load more results" : "次の結果を読み込む",
@@ -146,8 +267,8 @@ OC.L10N.register(
     "Account name" : "アカウント名",
     "Server side authentication failed!" : "サーバーサイドの認証に失敗しました！",
     "Please contact your administrator." : "管理者にお問い合わせください。",
-    "Temporary error" : "一時的なエラー",
-    "Please try again." : "もう一度お試しください。",
+    "Session error" : "セッションエラー",
+    "It appears your session token has expired, please refresh the page and try again." : "セッショントークンの有効期限が切れました。ページを更新して再度お試しください。",
     "An internal error occurred." : "内部エラーが発生しました。",
     "Please try again or contact your administrator." : "もう一度やり直してみるか、管理者にお問い合わせください。",
     "Password" : "パスワード",
@@ -300,9 +421,9 @@ OC.L10N.register(
     "Admin" : "管理",
     "Help" : "ヘルプ",
     "Access forbidden" : "アクセスが禁止されています",
+    "Back to %s" : "%s に戻る",
     "Page not found" : "ページが見つかりません",
     "The page could not be found on the server or you may not be allowed to view it." : "サーバーからページを見つけられなかった、もしくは閲覧が許可されていないようです。",
-    "Back to %s" : "%s に戻る",
     "Too many requests" : "要求が多すぎます",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "ネットワークからのリクエストが多すぎました。このようなエラーが発生した場合は、後で再試行するか、管理者に連絡してください。",
     "Error" : "エラー",
@@ -378,16 +499,12 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "このサーバー %s は現在メンテナンスモードです。しばらくお待ちください。",
     "This page will refresh itself when the instance is available again." : "この画面は、サーバー の再起動後に自動的に更新されます。",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "このメッセージが引き続き、または予期せず現れる場合は、システム管理者に問い合わせてください。",
-    "Currently open" : "編集中",
-    "Login with username or email" : "ログインするユーザー名またはメールアドレス",
-    "Login with username" : "ログインするユーザー名",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "チャット、ビデオ通話、画面共有、オンラインミーティング、ウェブ会議 - ブラウザーとモバイルアプリで。",
     "You have not added any info yet" : "まだ情報が追加されていません",
     "{user} has not added any info yet" : "{user}が、まだ情報を追加していません",
     "Error opening the user status modal, try hard refreshing the page" : "ユーザーステータスモーダルを開くときにエラーが発生しました。ページを更新してみてください",
     "Edit Profile" : "プロフィールを編集",
     "The headline and about sections will show up here" : "見出しと概要セクションがここに表示されます",
-    "Error loading message template: {error}" : "メッセージテンプレートの読み込みエラー: {error}",
     "Very weak password" : "非常に弱いパスワード",
     "Weak password" : "弱いパスワード",
     "So-so password" : "まずまずのパスワード",
