@@ -35,16 +35,16 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Clicat sul boton seguent per reïnicializar vòstre senhal. S’avètz pas demandat sa reïnicializacion, ignoratz aqueste corrièl.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Clicat sul ligam seguent per reïnicializar vòstre senhal. S’avètz pas demandat sa reïnicializacion, ignoratz aqueste corrièl.",
     "Reset your password" : "Reïnicializatz vòstre senhal",
-    "Nextcloud Server" : "Servidor Nextcloud",
-    "Some of your link shares have been removed" : "D’unes de vòstres ligams de partiment foguèron tirats",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "A causa d’una avaria de seguretat nos calguèt tirar certans de vòstres ligams de partiment. Vejatz lo ligam per mai d’informacions.",
-    "Learn more ↗" : "Ne saber mai ↗",
-    "Preparing update" : "Preparacion de la mesa a jorn",
     "[%d / %d]: %s" : "[%d / %d] : %s",
     "Repair step:" : "Etapa de reparacion :",
     "Repair info:" : "Info de reparacion :",
     "Repair warning:" : "Avertiment de reparacion :",
     "Repair error:" : "Error de reparacion :",
+    "Nextcloud Server" : "Servidor Nextcloud",
+    "Some of your link shares have been removed" : "D’unes de vòstres ligams de partiment foguèron tirats",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "A causa d’una avaria de seguretat nos calguèt tirar certans de vòstres ligams de partiment. Vejatz lo ligam per mai d’informacions.",
+    "Learn more ↗" : "Ne saber mai ↗",
+    "Preparing update" : "Preparacion de la mesa a jorn",
     "Turned on maintenance mode" : "Mòde manteniment aviat",
     "Turned off maintenance mode" : "Mòde manteniment atudat",
     "Maintenance mode is kept active" : "Lo mòde manteniment ten d’èsser actiu",
@@ -59,6 +59,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatible)",
     "The following apps have been disabled: %s" : "Las aplicacions seguentas son estadas desactivadas : %s",
     "Already up to date" : "Ja a jorn",
+    "Unknown" : "Desconegut",
     "Error occurred while checking server setup" : "Error producha pendent la verificacion de l’installacion del servidor",
     "unknown text" : "tèxt desconegut",
     "Hello world!" : "Adieu monde !",
@@ -75,73 +76,92 @@ OC.L10N.register(
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La mesa a jorn a pas reüssit. Mai mai d’informacions <a href=\"{url}\">visitatz nòstra publicacion al forum</a> que tracta d’aqueste problèma.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La mesa a jorn a pas reüssit. Mercés de senhalar aqueste problèma a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunautat Nexcloud</a>.",
     "Continue to {productName}" : "Contunhar cap a {productName}",
+    "Apps" : "Aplicacions",
     "More apps" : "Mai d’aplicacions",
-    "Currently open" : "Actualament dobèrta",
     "_{count} notification_::_{count} notifications_" : ["{count} notificacion","{count} notificacions"],
     "No" : "No",
     "Yes" : "Yes",
+    "Searching …" : "Recèrca…",
+    "Start typing to search" : "Començatz de picar per recercar",
+    "Today" : "Uèi",
+    "Date" : "Data",
+    "People" : "Gent",
+    "Load more results" : "Cargar mai de resultats",
     "Log in" : "Connexion",
     "Logging in …" : "Identificacion…",
+    "Log in to {productName}" : "Se connectar a {productName}",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Avèm detectat mantun ensag invalid de connexion a partir de vòstra IP. Per consequent vòstra connexion venenta serà en pausa per 30 segondas.",
+    "Account name or email" : "Nom d’utilizaire o email",
     "Server side authentication failed!" : "Autentificacion costat servidor fracassada !",
     "Please contact your administrator." : "Mercés de contactar vòstre administrator.",
     "An internal error occurred." : "Una error intèrna s’es producha.",
     "Please try again or contact your administrator." : "Tornatz ensajar o contactatz vòstre administrator.",
     "Password" : "Senhal",
-    "Log in to {productName}" : "Se connectar a {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Avèm detectat mantun ensag invalid de connexion a partir de vòstra IP. Per consequent vòstra connexion venenta serà en pausa per 30 segondas.",
-    "Account name or email" : "Nom d’utilizaire o email",
     "Log in with a device" : "Connexion amb un periferic",
     "Your account is not setup for passwordless login." : "Vòstre compte es pas parametrat per una autentificacion sens senhal.",
-    "Browser not supported" : "Navegador pas pres en carga",
-    "Passwordless authentication is not supported in your browser." : "L’autentificacion sens senhal es pas presa en cargar per vòstre navegador.",
     "Your connection is not secure" : "Vòstra connexion es pas segura",
     "Passwordless authentication is only available over a secure connection." : "L’autentificacion sens senhal es sonque disponibla via una connexion segura.",
+    "Browser not supported" : "Navegador pas pres en carga",
+    "Passwordless authentication is not supported in your browser." : "L’autentificacion sens senhal es pas presa en cargar per vòstre navegador.",
     "Reset password" : "Reïnicializar senhal",
+    "Back to login" : "Tornar a la connexion",
     "Couldn't send reset email. Please contact your administrator." : "Impossible de mandar lo corrièl de reïnicializacion. Contactatz vòstre administrator.",
     "Password cannot be changed. Please contact your administrator." : "Se pòt pas cambiar lo senhal. Mercés de contactar vòstre administrator.",
-    "Back to login" : "Tornar a la connexion",
     "New password" : "Senhal novèl",
     "I know what I'm doing" : "Sabi çò que fau",
     "Resetting password" : "Reïnicializacion de senhal",
+    "Schedule work & meetings, synced with all your devices." : "Planificatz prètzfaches e reünions, sincronizats amb totes vòstres periferics.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Gardatz vòstres companhs e amics a un sòl lòc sens divulgar lor vida privada.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicacion simpla e simpatica de corrièl integrada a Fichièrs, Contactes e Calendièr.",
     "Recommended apps" : "Aplicacions recomandadas",
     "Loading apps …" : "Cargament aplicacions…",
-    "Installing apps …" : "Installacion aplicacions…",
     "App download or installation failed" : "Telecargament o installacion de l’aplicacion fracassada",
     "Cannot install this app because it is not compatible" : "Impossibla d’installar aquesta app perque es pas compatibla",
     "Cannot install this app" : "Impossible d’installar aquesta app",
     "Skip" : "Sautar",
+    "Installing apps …" : "Installacion aplicacions…",
     "Install recommended apps" : "Installar las aplicacions recomandadas",
-    "Schedule work & meetings, synced with all your devices." : "Planificatz prètzfaches e reünions, sincronizats amb totes vòstres periferics.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Gardatz vòstres companhs e amics a un sòl lòc sens divulgar lor vida privada.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicacion simpla e simpatica de corrièl integrada a Fichièrs, Contactes e Calendièr.",
+    "Settings menu" : "Menú paramètres",
+    "Loading your contacts …" : "Cargaments dels contactes…",
+    "Looking for {term} …" : "Recèrca de {term}…",
     "Search contacts" : "Cercar pels contactes",
     "Reset search" : "Escafar la recèrca",
     "Search contacts …" : "Cercar pels contactes…",
     "Could not load your contacts" : "Cargament impossible de vòstres contactes",
     "No contacts found" : "Cap de contact pas trobat",
     "Install the Contacts app" : "Installar l’aplicacion Contactes",
-    "Loading your contacts …" : "Cargaments dels contactes…",
-    "Looking for {term} …" : "Recèrca de {term}…",
-    "Search for {name} only" : "Cercar sonque {name}",
-    "Start typing to search" : "Començatz de picar per recercar",
-    "Loading more results …" : "Cargament de mai de resultats…",
-    "Load more results" : "Cargar mai de resultats",
     "Search" : "Recercar",
     "No results for {query}" : "Cap de resultat per {query}",
     "An error occurred while searching for {type}" : "Una error s’es producha en cercant {type}",
+    "Search for {name} only" : "Cercar sonque {name}",
+    "Loading more results …" : "Cargament de mai de resultats…",
     "Forgot password?" : "Senhal oblidat ?",
     "Back" : "Retorn",
     "Login form is disabled." : "Lo formulari de connexion es desactivat.",
-    "Edit Profile" : "Modificar perfil",
-    "Search {types} …" : "Recèrca {types}…",
-    "Date" : "Data",
-    "Today" : "Uèi",
-    "People" : "Gent",
-    "Searching …" : "Recèrca…",
+    "More actions" : "Mai d’accions",
+    "Security warning" : "Avertiment de seguretat",
+    "Storage & database" : "Emmagazinatge & basa de donada",
+    "Data folder" : "Dossièr de donadas",
+    "Install and activate additional PHP modules to choose other database types." : "Installatz e activatz los modules PHP complementaris per causir d’autres tipes de basas de donadas.",
+    "For more details check out the documentation." : "Per mai de detalhs consultatz la documentacion.",
+    "Performance warning" : "Avertiment de performança",
+    "You chose SQLite as database." : "Causissètz SQLite coma basa de donadas.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite deu solament èsser utilizat per d’instàncias minimalas e de desvolopament. Per la produccion recomandam un autre sistèma de basa de donadas.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "S’utilizatz los clients per sincronizar de fichièrs, l’utilizacion de SQLite es forçadament descoratjada.",
+    "Database user" : "Utilizaire basa de donadas",
+    "Database password" : "Senhal basa de donadas",
+    "Database name" : "Nom basa de donadas",
+    "Database tablespace" : "Tablespace basa de donadas",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Volgatz especificar lo numèro de pòrt aprèp lo nom d’òste (ex : localhost:5432).",
+    "Database host" : "Òste basa de donadas",
+    "Installing …" : "Installacion...",
+    "Install" : "Installar",
+    "Need help?" : "Besonh d’ajuda ?",
+    "See the documentation" : "Vejatz la documentacion",
+    "{name} version {version} and above" : "{name} version {version} e ulterior",
     "This browser is not supported" : "Aqueste navigador es pas pres en carga",
     "Supported versions" : "Versions presas en carga",
-    "{name} version {version} and above" : "{name} version {version} e ulterior",
-    "Settings menu" : "Menú paramètres",
+    "Search {types} …" : "Recèrca {types}…",
     "Choose" : "Causir",
     "Copy" : "Copiar",
     "Move" : "Move",
@@ -171,11 +191,6 @@ OC.L10N.register(
     "Connect items to a project to make them easier to find" : "Connectatz d’elements a un projècte per lo rendre mai simples de trobar",
     "New in" : "Nòu dins",
     "View changelog" : "Veire jornal de modificacions",
-    "Very weak password" : "Senhal plan feble",
-    "Weak password" : "Senhal feble",
-    "So-so password" : "Senhal mejan",
-    "Good password" : "Bon senhal",
-    "Strong password" : "Senhal fòrt",
     "No action available" : "Cap d’accion pas disponibla",
     "Error fetching contact actions" : "Error en recuperacion las accions contacte",
     "Non-existing tag #{tag}" : "Etiqueta inexistenta #{tag}",
@@ -186,18 +201,14 @@ OC.L10N.register(
     "Collaborative tags" : "Etiquetas collaborativas",
     "No tags found" : "Cap d’etiqueta pas trobada",
     "Personal" : "Personal",
-    "Apps" : "Aplicacions",
     "Admin" : "Admin",
     "Help" : "Ajuda",
     "Access forbidden" : "Accès defendut",
-    "Profile not found" : "Perfil pas trobat",
-    "The profile does not exist." : "Lo perfil existís pas.",
     "Back to %s" : "Tornar a %s",
     "Page not found" : "Pagina pas trobada",
     "Too many requests" : "Tròp de requèstas",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "I a agut tròp de requèstas a partir de vòstre ret. Tornatz ensajar mai tard o contactatz vòstre administrator s’aquò es una error.",
     "Error" : "Error",
-    "Previous" : "Precedent",
     "Internal Server Error" : "Error intèrna del servidor",
     "The server was unable to complete your request." : "Lo servidor a pas pogut terminar vòstra requèsta.",
     "If this happens again, please send the technical details below to the server administrator." : "S’aquò tòrna arribar, enviatz lo detalhs tecnics çai-jos a l’administrator del servidor.",
@@ -211,31 +222,6 @@ OC.L10N.register(
     "File: %s" : "Fichièr : %s",
     "Line: %s" : "Linha : %s",
     "Trace" : "Traça",
-    "Security warning" : "Avertiment de seguretat",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vòstre repertòri de donadas e vòstres fichièrs son probablament accessibles a partir d’internet pr’amor que lo fichièr .htaccess fonciona pas.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per d’informacions per corrèctament configurar vòstre servidor, consultatz la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentacion</a>.",
-    "Create an <strong>admin account</strong>" : "Crear un <strong>compte admin</strong>",
-    "Show password" : "Mostrar lo senhal",
-    "Toggle password visibility" : "Alternar la visibilitat del senhal",
-    "Storage & database" : "Emmagazinatge & basa de donada",
-    "Data folder" : "Dossièr de donadas",
-    "Configure the database" : "Configurar la basa de donadas",
-    "Only %s is available." : "Sonque %s es disponible.",
-    "Install and activate additional PHP modules to choose other database types." : "Installatz e activatz los modules PHP complementaris per causir d’autres tipes de basas de donadas.",
-    "For more details check out the documentation." : "Per mai de detalhs consultatz la documentacion.",
-    "Database password" : "Senhal basa de donadas",
-    "Database name" : "Nom basa de donadas",
-    "Database tablespace" : "Tablespace basa de donadas",
-    "Database host" : "Òste basa de donadas",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Volgatz especificar lo numèro de pòrt aprèp lo nom d’òste (ex : localhost:5432).",
-    "Performance warning" : "Avertiment de performança",
-    "You chose SQLite as database." : "Causissètz SQLite coma basa de donadas.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite deu solament èsser utilizat per d’instàncias minimalas e de desvolopament. Per la produccion recomandam un autre sistèma de basa de donadas.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "S’utilizatz los clients per sincronizar de fichièrs, l’utilizacion de SQLite es forçadament descoratjada.",
-    "Install" : "Installar",
-    "Installing …" : "Installacion...",
-    "Need help?" : "Besonh d’ajuda ?",
-    "See the documentation" : "Vejatz la documentacion",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Sembla que sètz a reïnstallar vòstre Nextcloud. Pasmens lo fichièr CAN_INSTALL es absent del repertòri config. Volgatz ben crear lo fichièr CAN_INSTALL dins vòstre dossièr config per contunhar.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Supression impossibla de CAN_INSTALL dins lo repertòri config. Mercés de lo tirar manualament.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aquesta aplicacion requerís JavaScript per foncionar coma cal. {linkstart}Activatz JavaScript{linkend} e recargatz la pagina.",
@@ -247,12 +233,14 @@ OC.L10N.register(
     "Please log in before granting %1$s access to your %2$s account." : "Autentificatz-vos abans de donnar l’accès a %1$s a vòstre compte %2$s.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se ensajatz pas de configurar un periferic novèl o una aplicacion novèla, qualqu’un ensaja de vos far donar accès a vòstras donadas. En aqueste cas, contunhetz pas e contactatz vòstre administrator sistèma.",
     "Grant access" : "Donar accès",
+    "Alternative log in using app password" : "Connexion alternativa en utilizant un senhal d’aplicacion",
     "Account access" : "Accès compte",
     "Currently logged in as %1$s (%2$s)." : "Actualament connectat coma %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Sètz a mand de donar accès a vòstra compte %2$s a %1$s.",
     "Account connected" : "Compte connectat",
     "Your client should now be connected!" : "Vòstre client deu èsser connectat ara !",
     "You can close this window." : "Podètz tampar aquesta fenèstra.",
+    "Previous" : "Precedent",
     "This share is password-protected" : "Aqueste partiment es protegit per un senhal",
     "Email address" : "Adreça mail",
     "Password sent!" : "Senhal enviat !",
@@ -285,64 +273,19 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "L’instància %s es actualament en mòde manteniment, pòt trigar.",
     "This page will refresh itself when the instance is available again." : "Aquesta pagina s’actualizarà soleta quand l’instància serà disponibla de nòu.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactatz l’administrator sistèma s’aqueste messatge ten d’aparéisser o apareis sens rason.",
-    "The user limit of this instance is reached." : "Lo limit d’utilizaires d’aquesta instància es atengut.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Sembla que vòstre servidor es pas configurat corrèctament per permetre la sincronizacion de fichièrs, perque l’interfàcia WebDAV sembla copada.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP sembla corrèctament configurat per interpretar las variablas d’environament del sistèma. La pròva amb getenv(\"PATH\") a pas tornar una responda voida.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuracion lectura-sola es estada activada. Aquò empacha de configurar d’unes paramètres via l’interfàcia web. Pasmens, òm deu far venir lo fichièr modificable manualament per cada mesa a jorn.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vòstra basa de donada s’executa pas amb la transaccion de nivèl d’isolacion « READ COMMITTED ». Aquò pòt causar problèmas quand mantuna accion s’executan en parallèl.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Manca lo module « fileinfo » de PHP. Se recomanda d’activar aqueste modul per obténer los melhors resultats amb la deteccion de tipe MIME.",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Vòstra installacion a pas cap de de region telefonica per defaut. Aquò es requerit per validar lo numèros de telefòn als paramètres de perfil sens còdi país. Per autorizar los numèros sens còdi país, apondètz « default_phone_region » amb lo {linkstart}còdi ISO 3166-1↗{linkend}  correspondent de la region dins vòstre fichièr config.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Èra pas possible d’executar lo prètzfach cron via CLI. Las errors tecnicas seguentas an aparegut :",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La foncion « set_time_limit\" » es pas disponibla. Aquò poiriá menar a una execucion copada al mièg camin, e a una copadura de l’installacion. L’activacion d’aquesta foncion es forçadament recomandada.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vòstre PHP prend pas en carga FreeType, çò que causa lo rompement dels imatges de perfil e de l’interfàcia de paramètres.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Indèx absent « {indexName} » dins la taula « {tableName} ».",
-    "Missing primary key on table \"{tableName}\"." : "Manca la clau primària de la taula « {tableName} ».",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Manca la colomna opcionala « {columnName} » a la taula « {tableName} ».",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Mancan d’unes modules PHP recomandats a aquesta instància. Per de melhoras performanças e una melhora compatibilitat es forçadament recomandat de los installar.",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Lo module php-imagick d’aquesta instància a pas cap de compatibilitat SVG. Es forçadament recomandant de l’installar per una melhora compatibilitat.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite es actualament utilizat per la basa de donadas. Per d’installacions mai grandas vos recomandam de bascular sus un autre gestionari de basa de donadas.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Es particularament recomandat pendent l’utilizacion de client burèu per la sincronizacion de fichièrs.",
-    "The PHP memory limit is below the recommended value of 512MB." : "La memòria limit PHP es jos la valor recomandada de 512 Mo.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "D’unes repertòris d’aplicacion son la proprietat d’un utilizaire diferent qu’aquel del servidor web. Aquò pòt èsser lo cas se las aplicacions foguèron installadas manualament. Verificatz las permission dels repertòris d’aplicacion seguents :",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "L’entèsta HTTP « {header} » es pas definida a « {expected} ». Aquò es un risc de seguretat o de vida privada, es recomandat d’ajustar aqueste paramètre en consequéncia.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "L’entèsta HTTP « {header} » es pas definida a « {expected} ». D’unas foncionalitats poirián foncionar pas corrèctament, es recomandat d’ajustar aqueste paramètre en consequéncia.",
-    "Wrong username or password." : "Marrit nom d’utilizaire o senhal.",
-    "User disabled" : "Utilizaire desactivat",
-    "Username or email" : "Nom d’utilizaire o senhal",
-    "Start search" : "Aviar la recèrca",
-    "Open settings menu" : "Dobrir lo menú de paramètres",
-    "Settings" : "Paramètres",
-    "Avatar of {fullName}" : "Avatar de {fullName}",
-    "Show all contacts …" : "Mostrar totes los contactes…",
-    "No files in here" : "Cap de fichièr aicí",
-    "New folder" : "Novèl dorsièr",
-    "No more subfolders in here" : "Cap de jos-dossièr aicí",
-    "Name" : "Nom",
-    "Size" : "Talha",
-    "Modified" : "Modificat",
-    "\"{name}\" is an invalid file name." : "\"{name}\" es pas un nom de fichièr valid.",
-    "File name cannot be empty." : "Lo nom de fichièr pòt pas èsser void.",
-    "\"/\" is not allowed inside a file name." : "« / » es pas permés dins un nom de fichièr.",
-    "\"{name}\" is not an allowed filetype" : "« {name} » es pas un tipe de fichièr permés",
-    "{newName} already exists" : "{newName} existís ja",
-    "Error loading file picker template: {error}" : "Error de cargament del modèl del selector de fichièr : {error}",
-    "Error loading message template: {error}" : "Error de cargament del modèl de messatge : {error}",
-    "Show list view" : "Afichar la vista en lista",
-    "Show grid view" : "Afichar la vista en grasilha",
-    "Pending" : "En espèra",
-    "Home" : "Domicili",
-    "Copy to {folder}" : "Copiar a {folder}",
-    "Move to {folder}" : "Desplaçar a {folder}",
-    "Authentication required" : "Autentificacion requerida",
-    "This action requires you to confirm your password" : "Aquesta accions vos demanda de confirmar vòstre senhal",
-    "Confirm" : "Confirmar",
-    "Failed to authenticate, try again" : "Autentificacion pas reüssida, tornatz ensajar",
-    "Users" : "Utilizaires",
-    "Username" : "Nom d'utilizaire",
-    "Database user" : "Utilizaire basa de donadas",
-    "Confirm your password" : "Confirmatz lo senhal",
-    "App token" : "Geton aplicacion",
-    "Alternative log in using app token" : "Autentificacion alternativa en utilizant un geton d’aplicacion",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Mercés d’utilizar l’aisina de mesa a jorn en linha de comanda s’avètz una brava instància de mai de 50 utilizaires."
+    "Edit Profile" : "Modificar perfil",
+    "Very weak password" : "Senhal plan feble",
+    "Weak password" : "Senhal feble",
+    "So-so password" : "Senhal mejan",
+    "Good password" : "Bon senhal",
+    "Strong password" : "Senhal fòrt",
+    "Profile not found" : "Perfil pas trobat",
+    "The profile does not exist." : "Lo perfil existís pas.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vòstre repertòri de donadas e vòstres fichièrs son probablament accessibles a partir d’internet pr’amor que lo fichièr .htaccess fonciona pas.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per d’informacions per corrèctament configurar vòstre servidor, consultatz la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentacion</a>.",
+    "Show password" : "Mostrar lo senhal",
+    "Toggle password visibility" : "Alternar la visibilitat del senhal",
+    "Configure the database" : "Configurar la basa de donadas",
+    "Only %s is available." : "Sonque %s es disponible."
 },
 "nplurals=2; plural=(n > 1);");
