@@ -27,6 +27,7 @@ OC.L10N.register(
     "Could not complete login" : "Nie je možné dokončiť prihlásenie",
     "State token missing" : "Chýba stavový token",
     "Your login token is invalid or has expired" : "Váš prihlasovací token je neplatný alebo jeho platnosť skončila",
+    "Please use original client" : "Použite prosím originálneho klienta",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Toto komunitné vydanie Nextcloud nie je podporované a push upozornenia nie sú k dispozícii.",
     "Login" : "Prihlásiť sa",
     "Unsupported email length (>255)" : "Dĺžka emailovej správy nie je podporovaná (>255)",
@@ -51,6 +52,11 @@ OC.L10N.register(
     "No translation provider available" : "Nie je dostupný žiadny poskytovateľ prekladu",
     "Could not detect language" : "Nepodarilo sa zistiť jazyk",
     "Unable to translate" : "Nie je možné preložiť",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Krok opravy:",
+    "Repair info:" : "Informácie o oprave:",
+    "Repair warning:" : "Varovanie o oprave:",
+    "Repair error:" : "Chyba opravy:",
     "Nextcloud Server" : "Nextcloud Server",
     "Some of your link shares have been removed" : "Niektoré odkazy so sprístupnením boli odstránené.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Kvôli bezpečnostnej chyba sme museli odstrániť niektoré z vašich odkazov pre zdieľanie. Pre viac informácií nasledujte tento link.",
@@ -58,11 +64,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Zadajte svoj kľúč predplatného v aplikácii podpory, aby ste zvýšili limit pre množstvo účtov. To vám tiež poskytuje všetky ďalšie výhody, ktoré Nextcloud Enterprise ponúka a je vysoko odporúčaný pre prevádzku vo firemnom prostredí.",
     "Learn more ↗" : "Viac informácií ↗",
     "Preparing update" : "Pripravuje sa aktualizácia",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Krok opravy:",
-    "Repair info:" : "Informácie o oprave:",
-    "Repair warning:" : "Varovanie o oprave:",
-    "Repair error:" : "Chyba opravy:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Prosím, použite aktualizáciu z príkazového riadka, pretože aktualizácia cez prehliadač je zakázaná vo vašom config.php.",
     "Turned on maintenance mode" : "Mód údržby je zapnutý",
     "Turned off maintenance mode" : "Mód údržby je vypnutý",
@@ -79,6 +80,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nekompatibilná)",
     "The following apps have been disabled: %s" : "Nasledujúce aplikácie boli vypnuté: %s",
     "Already up to date" : "Už aktuálne",
+    "Unknown" : "Neznámy",
     "Error occurred while checking server setup" : "Počas kontroly nastavenia serveru sa stala chyba",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Viac podrobností nájdete v {linkstart}dokumentácii ↗{linkend}.",
     "unknown text" : "neznámy text",
@@ -146,8 +148,8 @@ OC.L10N.register(
     "Account name" : "Názov účtu",
     "Server side authentication failed!" : "Autentifikácia na serveri zlyhala!",
     "Please contact your administrator." : "Kontaktujte prosím vášho administrátora.",
-    "Temporary error" : "Dočasná chyba",
-    "Please try again." : "Prosím skúste to znova.",
+    "Session error" : "Chyba relácie",
+    "It appears your session token has expired, please refresh the page and try again." : "Zdá sa, že platnosť vášho tokenu relácie vypršala, obnovte stránku a skúste to znova.",
     "An internal error occurred." : "Došlo k vnútornej chybe.",
     "Please try again or contact your administrator." : "Skúste to znovu, alebo sa obráťte na vášho administrátora.",
     "Password" : "Heslo",
@@ -207,9 +209,25 @@ OC.L10N.register(
     "Login form is disabled." : "Prihlasovací formulár je vypnutý.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Prihlasovanie do Nextcloud je zakázané. Použite inú možnosť prihlásenia, ak je k dispozícii, alebo kontaktujte svojho administrátora.",
     "More actions" : "Viac akcií",
+    "Password is too weak" : "Heslo je príliš jednoduché",
+    "Password is weak" : "Heslo je jednoduché",
+    "Password is average" : "Heslo je priemerné",
+    "Password is strong" : "Heslo je silné",
+    "Password is very strong" : "Heslo je veľmi silné",
+    "Password is extremely strong" : "Heslo je extrémne silné",
+    "Unknown password strength" : "Neznáma sila hesla",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Váš priečinok s dátami a súbormi je pravdepodobne dostupný z internetu, pretože súbor <code>.htaccess</code> nefunguje.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Pre informácie o tom, ako správne nakonfigurovať server, prosím navštívte {linkStart} dokumentáciu {linkEnd}",
+    "Autoconfig file detected" : "Detekovaný súbor automatickej konfigurácie",
+    "The setup form below is pre-filled with the values from the config file." : "Inštalačný formulár nižšie je vopred vyplnený hodnotami z konfiguračného súboru.",
     "Security warning" : "Bezpečnostné varovanie",
+    "Create administration account" : "Vytvoriť účet administrátora",
+    "Administration account name" : "Názov účtu administrátora",
+    "Administration account password" : "Heslo účtu administrátora",
     "Storage & database" : "Úložisko & databáza",
     "Data folder" : "Priečinok dát",
+    "Database configuration" : "Konfigurácia Databáze",
+    "Only {firstAndOnlyDatabase} is available." : "Je dostupná iba {firstAndOnlyDatabase}",
     "Install and activate additional PHP modules to choose other database types." : "Pri výbere iného typu databázy bude potrebné nainštalovať a aktivovať ďalšie PHP moduly.",
     "For more details check out the documentation." : "Viac informácií nájdete v dokumentácii.",
     "Performance warning" : "Varovanie o výkone",
@@ -222,6 +240,7 @@ OC.L10N.register(
     "Database tablespace" : "Tabuľkový priestor databázy",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadajte číslo portu spolu s názvom hostiteľa (napr. localhost:5432).",
     "Database host" : "Server databázy",
+    "localhost" : "localhost",
     "Installing …" : "Inštalujem ...",
     "Install" : "Inštalovať",
     "Need help?" : "Potrebujete pomoc?",
@@ -283,9 +302,9 @@ OC.L10N.register(
     "Admin" : "Administrácia",
     "Help" : "Pomoc",
     "Access forbidden" : "Prístup odmietnutý",
+    "Back to %s" : "Späť na %s",
     "Page not found" : "Stránka nenájdená",
     "The page could not be found on the server or you may not be allowed to view it." : "Túto stránku sa nepodarilo na serveri nájsť alebo nemáte oprávnenie na jej zobrazenie.",
-    "Back to %s" : "Späť na %s",
     "Too many requests" : "Priveľa požiadavok",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Príliš mnoho požiadaviek z vašej siete. Skúste to znovu neskôr alebo kontaktujte svojho administrátora ak je toto chyba.",
     "Error" : "Chyba",
@@ -317,7 +336,7 @@ OC.L10N.register(
     "Grant access" : "Povoliť prístup",
     "Alternative log in using app password" : "Alternatívne prihlásenie pomocou hesla aplikácie",
     "Account access" : "Prístup k účtu",
-    "Currently logged in as %1$s (%2$s)." : "Momentálne prihlásený ako %1$s (%2$s).",
+    "Currently logged in as %1$s (%2$s)." : "Momentálne ste prihlásený ako %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Chystáte sa udeliť %1$s prístup k svojmu %2$s účtu.",
     "Account connected" : "Účet pripojený",
     "Your client should now be connected!" : "Váš klient by mal byť pripojený!",
@@ -361,16 +380,12 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Táto %s inštancia je v súčasnej dobe v režime údržby. Počkajte prosím.",
     "This page will refresh itself when the instance is available again." : "Táto stránka sa obnoví sama hneď ako bude inštancia znovu dostupná.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktujte prosím správcu systému, ak sa táto správa objavuje opakovane alebo neočakávane.",
-    "Currently open" : "V súčasnosti otvorené",
-    "Login with username or email" : "Prihlásiť sa pomocou užívateľského mena alebo e-mailu",
-    "Login with username" : "Prihlásiť sa s užívateľským menom",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Četovanie, videohovory, zdieľanie obrazovky, online stretnutia a webové konferencie - vo vašom prehliadači a pomocou mobilných aplikácií.",
     "You have not added any info yet" : "Zatiaľ ste nepridali žiadne informácie",
     "{user} has not added any info yet" : "{user} zatiaľ nepridal žiadne informácie",
     "Error opening the user status modal, try hard refreshing the page" : "Chyba pri otváraní modálneho okna stavu používateľa, skúste stránku obnoviť",
     "Edit Profile" : "Upraviť rofil",
     "The headline and about sections will show up here" : "Tu sa zobrazí titul a sekcia Informácie",
-    "Error loading message template: {error}" : "Chyba pri nahrávaní šablóny správy: {error}",
     "Very weak password" : "Veľmi slabé heslo",
     "Weak password" : "Slabé heslo",
     "So-so password" : "Priemerné heslo",
