@@ -52,6 +52,11 @@ OC.L10N.register(
     "No translation provider available" : "Постачальник послуг перекладу недоступний",
     "Could not detect language" : "Не вдалося визначити мову",
     "Unable to translate" : "Не вдалося перекласти",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Крок у відновленні:",
+    "Repair info:" : "Інформація про відновлення:",
+    "Repair warning:" : "Застереження щодо відновлення:",
+    "Repair error:" : "Помилка під час відновлення:",
     "Nextcloud Server" : "Сервер Nextcloud",
     "Some of your link shares have been removed" : "Окремі посилання на спільні елементи було вилучено",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Через ваду з безпекою ми вимушені були вилучити деякі ваші спільні посилання. Будь ласка, перегляньте цю докладну інформацію.",
@@ -59,11 +64,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Зазначте ваш ключ підписки у застосунку підтримки, щоб збільшити кількість дозволених облікових записів. Після цього ви отримаєте всі додаткові переваги, які надає Nextcloud для бізнесу. Ми рекомендуємо це зробити для комерційних користувачів.",
     "Learn more ↗" : "Дізнайтеся більше ↗",
     "Preparing update" : "Підготовка оновлення",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Крок у відновленні:",
-    "Repair info:" : "Інформація про відновлення:",
-    "Repair warning:" : "Застереження щодо відновлення:",
-    "Repair error:" : "Помилка під час відновлення:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Будь ласка, скористайтеся оновленням через командний рядок, оскільки оновлення через бравзер вимкнено у файлі налаштувань config.php.",
     "Turned on maintenance mode" : "Активовано режим технічного обслуговування",
     "Turned off maintenance mode" : "Вимкнено режим технічного обслуговування",
@@ -80,6 +80,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (несумісне)",
     "The following apps have been disabled: %s" : "Ці застосунки було вимкнено: %s",
     "Already up to date" : "Вже актуально",
+    "Unknown" : "Невідомо",
     "Error occurred while checking server setup" : "При перевірці налаштувань серверу сталася помилка",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Додаткову інформацію див. у {linkstart}документації ↗{linkend}.",
     "unknown text" : "невідомий текст",
@@ -301,9 +302,9 @@ OC.L10N.register(
     "Admin" : "Адміністратор",
     "Help" : "Допомога",
     "Access forbidden" : "Доступ заборонено",
+    "Back to %s" : "Назад до %s",
     "Page not found" : "Сторінку не знайдено",
     "The page could not be found on the server or you may not be allowed to view it." : "Не вдалося знайти сторінку на сервері або вам не дозволено її перегляд.",
-    "Back to %s" : "Назад до %s",
     "Too many requests" : "Забагато запитів",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Забагато запитів із вашої мережі. Повторіть спробу пізніше або зверніться до адміністратора, якщо це помилка.",
     "Error" : "Помилка",
@@ -379,16 +380,12 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Для сервера хмари %s увімкнено режим технічного обслуговування.",
     "This page will refresh itself when the instance is available again." : "Ця сторінка оновиться автоматично, коли сервер знову стане доступний.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Зверніться до вашого системного адміністратора, якщо це повідомлення не зникає або з'явилося несподівано.",
-    "Currently open" : "Наразі відкрито",
-    "Login with username or email" : "Увійти з ім'ям користувача або ел. поштою",
-    "Login with username" : "Увійти з ім'ям користувача",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Чати, відеовиклики, демонстрація екану, онлайнові зустрічі та вебконференції у вашому браузері та на мобільних застосунках.",
     "You have not added any info yet" : "Ви ще не додали жодної інформації",
     "{user} has not added any info yet" : "{user} ще не додав жодної інформації",
     "Error opening the user status modal, try hard refreshing the page" : "Помилка відкриття режиму статусу користувача. Спробуйте оновити сторінку",
     "Edit Profile" : "Редагувати профіль",
     "The headline and about sections will show up here" : "Тут відображатимуться заголовок і розділи про",
-    "Error loading message template: {error}" : "Помилка при завантаженні шаблону повідомлення: {error}",
     "Very weak password" : "Дуже слабкий пароль",
     "Weak password" : "Слабкий пароль",
     "So-so password" : "Такий собі пароль",
