@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Ziel existiert nicht",
     "Destination is not creatable" : "Ziel kann nicht erstellt werden",
     "Dot files are not allowed" : "Dateinamen mit einem Punkt am Anfang sind nicht erlaubt",
+    "%1$s (renamed)" : "%1$s (umbenannt)",
+    "renamed file" : "Umbenannte Datei",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" ist ein unzulässiger Datei- oder Ordnername.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" ist ein unzulässiges Präfix für Datei- oder Ordnernamen.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" ist in einem Datei- oder Ordnernamen unzulässig.",
@@ -101,7 +103,7 @@ OC.L10N.register(
     "Invalid parent path" : "Ungültiger übergeordneter Pfad",
     "File already exists" : "Datei bereits vorhanden",
     "Invalid path" : "Ungültiger Pfad",
-    "Failed to create file from template" : "Fehler beim Erstellen der Datei aus Vorlage",
+    "Failed to create file from template" : "Datei konnte nicht aus Vorlage erstellt werden",
     "Templates" : "Vorlagen",
     "Storage %s cannot be moved" : "Speicherplatz %s kann nicht verschoben werden",
     "Moving a share (%s) into a shared folder is not allowed" : "Verschieben einer Freigabe (%s) in einen freigegebenen Ordner ist unzulässig",
@@ -120,10 +122,10 @@ OC.L10N.register(
     "__language_name__" : "Deutsch (Persönlich: Du)",
     "This is an automatically sent email, please do not reply." : "Dies ist eine automatisch gesendete E-Mail. Bitte antworte nicht auf diese E-Mail.",
     "Help & privacy" : "Hilfe & Datenschutz",
-    "Appearance and accessibility" : "Erscheinungsbild und Barrierefreiheit",
+    "Appearance and accessibility" : "Aussehen und Barrierefreiheit",
     "Apps" : "Apps",
     "Personal settings" : "Persönliche Einstellungen",
-    "Administration settings" : "Verwaltungseinstellungen",
+    "Administration settings" : "Administrationseinstellungen",
     "Settings" : "Einstellungen",
     "Log out" : "Abmelden",
     "Accounts" : "Konten",
@@ -201,6 +203,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "Der Pfad ist bereits mit dieser Gruppe geteilt",
     "Link sharing is not allowed" : "Freigabe via Link ist nicht erlaubt",
     "Public upload is not allowed" : "Öffentliches Hochladen ist nicht erlaubt",
+    "You cannot share a folder that contains other shares" : "Ein Ordner, der andere Freigaben enthält, kann nicht geteilt werden",
     "Sharing is disabled" : "Teilen ist deaktiviert",
     "Sharing is disabled for you" : "Teilen ist für dich deaktiviert",
     "Cannot share with the share owner" : "Teilen mit dem Freigabeeigentümer nicht möglich",
@@ -272,6 +275,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Ein gültiger Anmeldename muss eingegeben werden.",
     "Login contains whitespace at the beginning or at the end" : "Anmeldename enthält Leerzeichen am Anfang oder am Ende",
     "Login must not consist of dots only" : "Der Anmeldename darf nicht nur aus Punkten bestehen",
+    "Username is too long" : "Benutzername ist zu lang",
     "Login is invalid because files already exist for this user" : "Der Anmeldename ist ungültig, da bereits Dateien von diesem Konto existieren",
     "Account disabled" : "Konto deaktiviert",
     "Login canceled by app" : "Anmeldung durch die App abgebrochen",
@@ -328,7 +332,6 @@ OC.L10N.register(
     "The audio to transcribe" : "Die Audio-Datei zum Transkribieren",
     "Transcription" : "Transkription",
     "The transcribed text" : "Der transkribierte Text",
-    "ContextAgent" : "ContextAgent",
     "Chat with an agent" : "Mit einem Agenten chatten",
     "Chat message" : "Chatnachricht",
     "A chat message to send to the agent." : "Eine Chatnachricht, die an den Agenten gesendet wird.",
@@ -363,6 +366,11 @@ OC.L10N.register(
     "How many images to generate" : "Wie viele Bilder erstellt werden sollen",
     "Output images" : "Ausgegebene Bilder",
     "The generated images" : "Die erstellten Bilder",
+    "Generate speech" : "Sprache erstellen",
+    "Generate speech from a transcript" : "Sprache aus einem Transkript erstellen",
+    "Write transcript that you want the assistant to generate speech from" : "Schreibe ein Transkript, aus dem der Assistent Sprache erstellen soll",
+    "Output speech" : "Sprachausgabe",
+    "The generated speech" : "Die erstellte Sprache",
     "Free text to text prompt" : "Freie Text-zu-Text-Eingabeaufforderung",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Führt eine beliebige Eingabeaufforderung mit einem Sprachmodell aus, das eine Antwort zurückgibt",
     "Describe a task that you want the assistant to do or ask a question" : "Eine Aufgabe beschreiben, die der Assistent erledigen soll, oder eine Frage stellen",
@@ -442,21 +450,8 @@ OC.L10N.register(
     "Generate headline" : "Überschrift erzeugen",
     "Summarizes text by reducing its length without losing key information." : "Fasst Text zusammen, indem die Länge reduziert wird, ohne dass wichtige Informationen verloren gehen.",
     "Extracts topics from a text and outputs them separated by commas." : "Extrahiert Themen aus einem Text und gibt sie durch Kommas getrennt aus.",
-    "Education Edition" : "Bildungsausgabe",
-    "File name is a reserved word" : "Der Dateiname ist ein reserviertes Wort",
-    "File name contains at least one invalid character" : "Der Dateiname enthält mindestens ein ungültiges Zeichen",
-    "File name is too long" : "Dateiname ist zu lang",
-    "Users" : "Benutzer",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s hat »%2$s« mit dir geteilt und möchte folgendes hinzufügen:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$shat »%2$s« mit dir geteilt und möchte folgendes hinzufügen",
-    "»%s« added a note to a file shared with you" : "»%s« hat eine Bemerkung zu einer mit dir geteilten Datei hinzugefügt",
-    "Open »%s«" : "»%s« öffnen",
-    "%1$s shared »%2$s« with you" : "%1$s hat »%2$s« mit dir geteilt",
-    "%1$s shared »%2$s« with you." : "%1$s hat »%2$s« mit dir geteilt.",
-    "Click the button below to open it." : "Klicke zum Öffnen auf die untere Schaltfläche.",
     "File is currently busy, please try again later" : "Die Datei ist in Benutzung, bitte versuche es später noch einmal",
     "Cannot download file" : "Datei kann nicht heruntergeladen werden.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Stelle sicher, dass eine Datei \".ocdata\" im Wurzelverzeichnis des data-Verzeichnisses existiert.",
-    "Path contains files shared with you" : "Der Pfad enthält für dich freigegebene Dateien"
+    "Login is too long" : "Die Anmeldung dauert zu lange"
 },
 "nplurals=2; plural=(n != 1);");
