@@ -38,6 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Se necesita la versión %s o superior del servidor.",
     "Server version %s or lower is required." : "Se necesita la versión %s o inferior del servidor.  ",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "El usuario que ha iniciado sesión debe ser un administrador, un sub-administrador o haber obtenido permisos especiales para acceder a esta configuración",
+    "Your current IP address doesn't allow you to perform admin actions" : "Su dirección IP actual no le permite ejecutar funciones de administrador",
     "Logged in account must be an admin or sub admin" : "La cuenta conectada debe ser de un administrador o un sub-administrador",
     "Logged in account must be an admin" : "La cuenta conectada debe ser un administrador",
     "Wiping of device %s has started" : "El borrado del dispositivo %s ha empezado",
@@ -92,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "El destino no existe",
     "Destination is not creatable" : "El destino no se puede crear",
     "Dot files are not allowed" : "Los archivos Dot no están permitidos",
+    "%1$s (renamed)" : "%1$s (renombrado)",
+    "renamed file" : "archivo renombrado",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" Es un nombre de archivo o carpeta no permitido.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "%1$s es un prefijo prohibido para nombres de archivo o carpeta.",
     "\"%1$s\" is not allowed inside a file or folder name." : "«%1$s» no se permite en el nombre de un archivo o carpeta.",
@@ -155,6 +158,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "No se pudo establecer la conexión a Oracle",
     "Oracle Login and/or password not valid" : "Usuario y/o contraseña de Oracle inválidos",
     "PostgreSQL Login and/or password not valid" : "Usuario y/o contraseña de PostgreSQL inválidos",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X no está soportado y %s no funcionará bien en esta plataforma. ¡Úsela bajo su propio riesgo! ",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obtener los mejores resultados, considera utilizar un servidor GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que esta instancia %s está funcionando en un entorno PHP de 32-bits y el open_basedir se ha configurado en php.ini. Esto acarreará problemas con archivos de tamaño superior a 4GB y resulta totalmente desaconsejado.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, quite el ajuste de open_basedir —dentro de su php.ini— o pásese a PHP de 64 bits.",
@@ -184,6 +188,7 @@ OC.L10N.register(
     "You cannot share your root folder" : "No puede compartir su carpeta raíz",
     "You are not allowed to share %s" : "Usted no está autorizado para compartir %s",
     "Valid permissions are required for sharing" : "Se requieren permisos válidos para compartir",
+    "File shares cannot have create or delete permissions" : "Las recursos compartidos de archivos no pueden tener permisos de creación o borrado",
     "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
     "Shares need at least read permissions" : "Los recursos compartidos requieren al menos permisos de lectura",
     "Files cannot be shared with delete permissions" : "Los archivos no se pueden compartir con permisos de borrado",
@@ -198,7 +203,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "La ruta ya se encuentra compartida con este grupo",
     "Link sharing is not allowed" : "La compartición de enlaces no está permitida",
     "Public upload is not allowed" : "No está permitida la subida de archivos pública",
-    "Path contains files shared with you" : "La ruta contiene archivos compartidos con Ud.",
+    "You cannot share a folder that contains other shares" : "No puede compartir una carpeta que contiene otros recursos compartidos",
     "Sharing is disabled" : "Compartir está deshabilitado",
     "Sharing is disabled for you" : "Compartir está deshabilitado para Ud.",
     "Cannot share with the share owner" : "No se puede compartir con el propietario del recurso compartido",
@@ -360,6 +365,11 @@ OC.L10N.register(
     "How many images to generate" : "Cuántas imágenes se generarán",
     "Output images" : "Imágenes de salida",
     "The generated images" : "Las imágenes generadas",
+    "Generate speech" : "Generar dictado",
+    "Generate speech from a transcript" : "Generar dictado desde una transcripción",
+    "Write transcript that you want the assistant to generate speech from" : "Escriba la transcripción desde la que desea que el asistente genere un dictado",
+    "Output speech" : "Dictado de salida",
+    "The generated speech" : "El dictado generado",
     "Free text to text prompt" : "Texto libre a prompt de texto",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Ejecuta un prompt arbitrario a través de un modelo de lenguaje que retorna una respuesta",
     "Describe a task that you want the assistant to do or ask a question" : "Describa una tarea que quiere que el asistente realice, o, haga una pregunta",
@@ -439,20 +449,8 @@ OC.L10N.register(
     "Generate headline" : "Generar titular",
     "Summarizes text by reducing its length without losing key information." : "Resume el texto reduciendo su longitud sin perder información clave.",
     "Extracts topics from a text and outputs them separated by commas." : "Extrae los tópicos de un texto y genera una salida separada por comas. ",
-    "Education Edition" : "Edición Educación",
-    "File name is a reserved word" : "El nombre de archivo es una palabra reservada",
-    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un carácter inválido",
-    "File name is too long" : "El nombre del archivo es demasiado largo",
-    "Users" : "Usuarios",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ha compartido «%2$s» contigo y quiere añadir:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s ha compartido «%2$s» contigo y quiere añadir",
-    "»%s« added a note to a file shared with you" : "«%s» ha añadido una nota a un archivo compartido contigo",
-    "Open »%s«" : "Abrir »%s« ",
-    "%1$s shared »%2$s« with you" : "%1$s ha compartido «%2$s» contigo",
-    "%1$s shared »%2$s« with you." : "%1$s ha compartido «%2$s» contigo.",
-    "Click the button below to open it." : "Haz clic en el botón de abajo para abrirlo.",
     "File is currently busy, please try again later" : "El archivo se encuentra actualmente ocupado, por favor inténtelo de nuevo más tarde",
     "Cannot download file" : "No se puede descargar el archivo",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrate de que existe un archivo llamado \".ocdata\" en la raíz del directorio de datos."
+    "Login is too long" : "El nombre de inicio de sesión es demasiado largo"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
