@@ -19,7 +19,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s y %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s y %5$s",
-    "Education Edition" : "Edición Educativa",
     "Enterprise bundle" : "Paquete empresarial",
     "Groupware bundle" : "Paquete de Groupware",
     "Hub bundle" : "Paquete Hub",
@@ -54,6 +53,7 @@ OC.L10N.register(
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
     "Files" : "Archivos",
     "View profile" : "Ver perfil",
+    "_%nh_::_%nh_" : ["%nh","%nh","%nh"],
     "Local time: %s" : "Hora local: %s",
     "today" : "hoy",
     "tomorrow" : "mañana",
@@ -76,14 +76,12 @@ OC.L10N.register(
     "seconds ago" : "hace segundos",
     "Empty file" : "Archivo vacío",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID: %sno existe. Por favor hablíitalo en tus configuraciones de aplicación o contacta a tu administrador.  ",
+    "Dot files are not allowed" : "Los archivos Dot no están permitidos",
     "File already exists" : "El archivo ya existe",
     "Invalid path" : "Ruta no válida",
     "Failed to create file from template" : "Error al crear el archivo a partir de la plantilla",
     "Templates" : "Plantillas",
-    "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
-    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
-    "File name is too long" : "El nombre del archivo es demasiado largo",
-    "Dot files are not allowed" : "Los archivos Dot no están permitidos",
+    "Filename contains at least one invalid character" : "El nombre del archivo contiene al menos un carácter inválido",
     "Empty filename is not allowed" : "El uso de nombres de archivo vacíos no está permitido",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "La aplicación \"%s\" no puede ser instalada porque el archivo appinfo no se puede leer. ",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "La aplicación \"%s\" no puede ser instalada porque no es compatible con esta versión del servidor. ",
@@ -95,7 +93,7 @@ OC.L10N.register(
     "Administration settings" : "Configuración de administración",
     "Settings" : "Ajustes",
     "Log out" : "Cerrar sesión",
-    "Users" : "Usuarios",
+    "Accounts" : "Cuentas",
     "Email" : "Correo electrónico",
     "Mail %s" : "Correo %s",
     "Fediverse" : "Fediverse",
@@ -118,7 +116,6 @@ OC.L10N.register(
     "You cannot use dots in the database name %s" : "No se pueden utilizar puntos en el nombre de la base de datos %s",
     "You need to enter details of an existing account." : "Necesitas ingresar los detalles de una cuenta existente.",
     "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "OS X de Mac no está soportado y %s no funcionará correctamente en esta plataforma ¡Úsalo bajo tu propio riesgo!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para mejores resultados, por favor cosidera usar en su lugar un servidor GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Al parecer esta instancia %s está corriendo en un ambiente PHP de 32-bits y el open_basedir ha sido configurado en el archivo php.ini. Esto generará problemas con archivos de más de 4GB de tamaño y es altamente desalentado. ",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor elimina el ajuste open_basedir de tu archivo php.ini o cambia a PHP de 64 bits. ",
@@ -127,11 +124,8 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend %s que comparte debe implementar la interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "No fue encontrado el Backend que comparte %s ",
     "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartió »%2$s« contigo y quiere añadir:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartió »%2$s« contigo y quiere añadir",
-    "»%s« added a note to a file shared with you" : "»%s« añadió una nota a un archivo compartido contigo",
-    "Open »%s«" : "Abrir »%s«",
     "%1$s via %2$s" : "%1$s a través de %2$s",
+    "Unknown share type" : "Tipo de elemento compartido desconocido",
     "You are not allowed to share %s" : "No tienes permitido compartir %s",
     "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
     "Files cannot be shared with delete permissions" : "No se pueden compartir archivos con permisos de eliminación",
@@ -139,9 +133,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "La fecha de expiración se encuentra en el pasado",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["No se puede establecer una fecha de caducidad más de %n día en el futuro","No se puede establecer una fecha de caducidad más de %n días en el futuro","No se puede establecer una fecha de caducidad más de %n días en el futuro"],
     "Sharing is only allowed with group members" : "Solo se permite compartir con miembros del grupo",
-    "%1$s shared »%2$s« with you" : "%1$s compartió »%2$s« contigo",
-    "%1$s shared »%2$s« with you." : "%1$s compartió »%2$s« contigo.",
-    "Click the button below to open it." : "Haz click en el botón inferior para abrirlo. ",
     "The requested share does not exist anymore" : "El recurso compartido solicitado ya no existe",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "No se creó el usuario porque se ha alcanzado el límite de usuarios. Consulta tus notificaciones para obtener más información.",
     "Could not find category \"%s\"" : "No fue posible encontrar la categoria \"%s\"",
@@ -194,8 +185,6 @@ OC.L10N.register(
     "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "No se puede instalar la aplicación \"%1$s\" porque no se cumplen las siguientes dependencias: %2$s",
     "a safe home for all your data" : "un lugar seguro para todos tus datos",
-    "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, por favor intentalo más tarde. ",
-    "Cannot download file" : "No se puede descargar el archivo",
     "Application is not enabled" : "La aplicación está deshabilitada",
     "Authentication error" : "Error de autenticación",
     "Token expired. Please reload page." : "La ficha ha expirado. Por favor recarga la página.",
@@ -226,7 +215,6 @@ OC.L10N.register(
     "Your data directory must be an absolute path." : "Tu directorio de datos debe ser una ruta absoluta.",
     "Check the value of \"datadirectory\" in your configuration." : "Verifica el valor de \"datadirectory\" en tu configuración.",
     "Your data directory is invalid." : "Tu directorio de datos no es válido.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegurate de que exista una archivo llamado \".ocdata\" en la raíz del directorio de datos. ",
     "Action \"%s\" not supported or implemented." : "La acción \"%s\" no está soportada o no está implementada.",
     "Authentication failed, wrong token or provider ID given" : "Falló la autenticación, se proporcionó un token o un ID de proveedor incorrecto",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Faltan parámetros para completar la solicitud. Parámetros faltantes: \"%s\"",
@@ -238,30 +226,14 @@ OC.L10N.register(
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
-    "404" : "404",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "El usuario que ha iniciado sesión debe ser un administrador, un subadministrador o tener permisos especiales para acceder a esta configuración.",
-    "Logged in user must be an admin or sub admin" : "El usuario que ha iniciado sesión debe ser un administrador o un subadministrador.",
-    "Logged in user must be an admin" : "El usuario firmado debe ser un administrador",
-    "Help" : "Ayuda",
-    "Unknown user" : "Ususario desconocido",
-    "Enter the database username and name for %s" : "Introduce el nombre de usuario y el nombre de la base de datos para %s",
-    "Enter the database username for %s" : "Introduce el nombre de usuario de la base de datos para %s",
-    "MySQL username and/or password not valid" : "Nombre de usuario y/o contraseña de MySQL no válidos",
-    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle inválidos",
-    "PostgreSQL username and/or password not valid" : "El Usuario y/o Contraseña de PostgreSQL inválido(s)",
-    "Set an admin username." : "Establecer un Usuario administrador",
-    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
-    "The username is already being used" : "Ese usuario ya está en uso",
-    "Could not create user" : "No fue posible crear el usuario",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Solo se permiten los siguientes caracteres en un nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", espacios y \"_.@-'\"",
-    "A valid username must be provided" : "Debes proporcionar un nombre de usuario válido",
-    "Username contains whitespace at the beginning or at the end" : "El usuario contiene un espacio en blanco al inicio o al final",
-    "Username must not consist of dots only" : "El usuario no debe consistir de solo puntos. ",
-    "Username is invalid because files already exist for this user" : "El nombre de usuario no es válido porque ya existen archivos para este usuario",
-    "User disabled" : "Usuario deshabilitado",
-    "PostgreSQL >= 9 required." : "Se requiere PostgreSQL >= 9.",
-    "Please upgrade your database version." : "Actualiza la versión de tu base de datos.",
-    "Your data directory is readable by other users." : "Tu directorio de datos es legible por otros usuarios.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambia los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. "
+    "Confirmation" : "Confirmación",
+    "Prompt" : "Promoción",
+    "Text" : "Texto",
+    "Summary" : "Resumen",
+    "Translate" : "Traducir",
+    "Target language" : "Lenguaje de destino",
+    "Result" : "Resultado",
+    "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, por favor intentalo más tarde. ",
+    "Cannot download file" : "No se puede descargar el archivo"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
