@@ -25,6 +25,7 @@ OC.L10N.register(
     "Invalid image" : "תמונה לא חוקית",
     "Avatar image is not square" : "התמונה המייצגת אינה מרובעת",
     "Files" : "קבצים",
+    "_%nh_::_%nh_" : ["שעה","שעתיים","%n שע׳"],
     "today" : "היום",
     "tomorrow" : "מחר",
     "yesterday" : "אתמול",
@@ -67,7 +68,6 @@ OC.L10N.register(
     "Additional settings" : "הגדרות נוספות",
     "You need to enter details of an existing account." : "עליך להקליד פרטים של חשבון קיים.",
     "Oracle connection could not be established" : "לא ניתן היה ליצור חיבור Oracle",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X אינו נתמך ו- %s לא יעבוד כשורה בפלטפורמה זו. ניתן לקחת סיכון ולהשתמש באחריותך! ",
     "For the best results, please consider using a GNU/Linux server instead." : "לתוצאות הכי טובות, יש לשקול שימוש בשרת GNU/Linux במקום.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "נראה ש- %s עובד על בסיס סביבת 32-bit PHP ושה- open_basedir הוגדר בקובץ php.ini. מצב זה יוביל לבעיות עם קבצים הגדולים מ- 4 GB ואינו מומלץ לחלוטין.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "יש להסיר את הגדרת open_basedir מתוך קובץ php.ini או להחליף לסביבת 64-bit PHP.",
@@ -75,14 +75,7 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "צד אחורי לשיתוף %s חייב ליישם את ממשק OCP\\Share_Backend",
     "Sharing backend %s not found" : "צד אחורי לשיתוף %s לא נמצא",
     "Sharing backend for %s not found" : "צד אחורי לשיתוף של %s לא נמצא",
-    "%1$s shared »%2$s« with you" : "%2$s שותף אתך על ידי %1$s",
-    "%1$s shared »%2$s« with you." : "„%2$s” שותף אתך על ידי %1$s.",
-    "Click the button below to open it." : "יש ללחוץ על הכפתור להלן כדי לפתוח אותו.",
-    "Open »%s«" : "פתיחת „%s”",
     "%1$s via %2$s" : "%1$s דרך %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s שיתף » %2$s« איתך, ורוצה להוסיף:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$sשיתף »%2$s« איתך, ורוצה להוסיף:",
-    "»%s« added a note to a file shared with you" : "התווספה הערה על קובץ ששותף את על ידי „%s”",
     "Unknown share type" : "סוג שיתוף אינו מוכר",
     "You are not allowed to share %s" : "אינך רשאי/ת לשתף %s",
     "Cannot increase permissions of %s" : "לא ניתן להוסיף על ההרשאות של %s",
@@ -137,7 +130,6 @@ OC.L10N.register(
     "A valid password must be provided" : "יש לספק ססמה תקנית",
     "Login canceled by app" : "התחברות בוטלה על ידי יישום",
     "a safe home for all your data" : "בית בטוח עבור כל המידע שלך",
-    "File is currently busy, please try again later" : "הקובץ בשימוש כרגע, יש לנסות שוב מאוחר יותר",
     "Application is not enabled" : "יישומים אינם מופעלים",
     "Authentication error" : "שגיאת הזדהות",
     "Token expired. Please reload page." : "פג תוקף. נא לטעון שוב את הדף.",
@@ -160,30 +152,10 @@ OC.L10N.register(
     "Storage connection error. %s" : "שגיאת חיבור אחסון. %s",
     "Storage is temporarily not available" : "האחסון אינו זמין כרגע",
     "Storage connection timeout. %s" : "פסק זמן חיבור אחסון. %s",
+    "Text" : "טקסט",
     "Summary" : "תקציר",
     "Translate" : "תרגום",
     "Result" : "תוצאה",
-    "Education Edition" : "מהדורה חינוכית",
-    "Logged in user must be an admin" : "על המשתמש שנכנס להיות מנהל",
-    "File name is a reserved word" : "שם קובץ הוא מילה שמורה",
-    "File name contains at least one invalid character" : "שם הקובץ כולל לפחות תו אחד לא חוקי",
-    "File name is too long" : "שם קובץ ארוך מדי",
-    "Help" : "עזרה",
-    "Users" : "משתמשים",
-    "Unknown user" : "משתמש לא ידוע",
-    "MySQL username and/or password not valid" : "שם המשתמש ו/או הססמה של MySQL אינם תקינים",
-    "Oracle username and/or password not valid" : "שם משתמש ו/או סיסמת Oracle אינם תקפים",
-    "PostgreSQL username and/or password not valid" : "שם משתמש ו/או סיסמת PostgreSQL אינם תקפים",
-    "Set an admin username." : "קביעת שם משתמש מנהל",
-    "Sharing %s failed, because this item is already shared with user %s" : "השיתוף %s נכשל, כיוון שהפריט כבר משותף עם משתמש %s",
-    "The username is already being used" : "השם משתמש כבר בשימוש",
-    "Could not create user" : "לא ניתן ליצור משתמש",
-    "A valid username must be provided" : "יש לספק שם משתמש תקני",
-    "Username contains whitespace at the beginning or at the end" : "שם המשתמש מכיל רווח בתחילתו או בסופו",
-    "Username must not consist of dots only" : "שם המשתמש לא יכול להיות מורכב מנקודות בלבד",
-    "Username is invalid because files already exist for this user" : "שם המשתמש שגוי כיוון שכבר קיימים קבצים למשתמש הזה",
-    "User disabled" : "משתמש מנוטרל",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "יש לשנות את ההרשאות ל- 0770 כך שהתיקייה לא תרשם על ידי משתמשים אחרים.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "נא לוודא שיש קובץ בשם „‎.ocdata” בבסיס תיקיית הנתונים שלך."
+    "File is currently busy, please try again later" : "הקובץ בשימוש כרגע, יש לנסות שוב מאוחר יותר"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
