@@ -87,7 +87,6 @@ OC.L10N.register(
     "Additional settings" : "Definições adicionais",
     "You need to enter details of an existing account." : "Precisa de introduzir detalhes de uma conta existente.",
     "Oracle connection could not be established" : "Não foi possível estabelecer a ligação Oracle",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Esta plataforma não suporta o sistema operativo Mac OS X e o %s poderá não funcionar corretamente. Utilize por sua conta e risco.",
     "For the best results, please consider using a GNU/Linux server instead." : "Para um melhor resultado, utilize antes o servidor GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que a instância %s está a ser executada num ambiente PHP de 32-bits e o open_basedir foi configurado no php.ini. Isto levará a problemas com ficheiros de tamanho superior a 4 GB e é altamente desencorajado.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a definição open_basedir do seu php.ini ou altere o seu PHP para 64-bits.",
@@ -176,20 +175,7 @@ OC.L10N.register(
     "Text" : "Texto",
     "Summary" : "Resumo",
     "Translate" : "Traduzir",
-    "Education Edition" : "Edição Educação",
-    "File name is a reserved word" : "Nome de ficheiro é uma palavra reservada",
-    "File name contains at least one invalid character" : "Nome de ficheiro contém pelo menos um caráter inválido",
-    "File name is too long" : "Nome do ficheiro demasiado longo",
-    "Users" : "Utilizadores",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s partilhado »%2$s« consigo e quer adicionar:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s partilhado »%2$s« consigo e quer adicionar:",
-    "»%s« added a note to a file shared with you" : "»%s« adicionou uma nota a um ficheiro partilhado consigo",
-    "Open »%s«" : "Abrir »%s«",
-    "%1$s shared »%2$s« with you" : "%1$s partilhado »%2$s« contigo",
-    "%1$s shared »%2$s« with you." : "%1$s partilhado »%2$s« contigo.",
-    "Click the button below to open it." : "Clicar no botão abaixo para abrir.",
     "File is currently busy, please try again later" : "O ficheiro está ocupado, por favor, tente mais tarde",
-    "Cannot download file" : "Não é possível transferir o ficheiro",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Garanta que existe um ficheiro chamado \".occdata\" na raiz do diretório de dados"
+    "Cannot download file" : "Não é possível transferir o ficheiro"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
