@@ -1,31 +1,9 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2016, ownCloud, Inc.
- *
- * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
- * @author Christoph Wurst <christoph@winzerhof-wurst.at>
- * @author Joas Schilling <coding@schilljs.com>
- * @author Jörn Friedrich Dreyer <jfd@butonic.de>
- * @author Lukas Reschke <lukas@statuscode.ch>
- * @author Morris Jobke <hey@morrisjobke.de>
- * @author Robin Appelman <robin@icewind.nl>
- * @author Roeland Jago Douma <roeland@famdouma.nl>
- * @author Thomas Müller <thomas.mueller@tmit.eu>
- *
- * @license AGPL-3.0
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program. If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
 namespace OCP;
 
@@ -142,7 +120,7 @@ interface IUserManager {
 	/**
 	 * @return IUser[]
 	 * @since 28.0.0
-	 * @since 29.0.2 $search parameter added
+	 * @since 30.0.0 $search parameter added
 	 */
 	public function getDisabledUsers(?int $limit = null, int $offset = 0, string $search = ''): array;
 
@@ -233,6 +211,17 @@ interface IUserManager {
 	 */
 	public function validateUserId(string $uid, bool $checkDataDirectory = false): void;
 
+	/**
+	 * Gets the list of users sorted by lastLogin, from most recent to least recent
+	 *
+	 * @param int|null $limit how many records to fetch
+	 * @param int $offset from which offset to fetch
+	 * @param string $search search users based on search params
+	 * @return list<string> list of user IDs
+	 * @since 30.0.0
+	 */
+	public function getLastLoggedInUsers(?int $limit = null, int $offset = 0, string $search = ''): array;
+
 	/**
 	 * Gets the list of users.
 	 * An iterator is returned allowing the caller to stop the iteration at any time.
@@ -240,7 +229,7 @@ interface IUserManager {
 	 *
 	 * @param int $offset from which offset to fetch
 	 * @return \Iterator<IUser> list of IUser object
-	 * @since 29.0.15
+	 * @since 32.0.0
 	 */
 	public function getSeenUsers(int $offset = 0): \Iterator;
 }
